// Monetary Policy and Net Exports Externalities in the Small Open Economy (Jae Hun Shim)

// Figure 2

@#define OPTIMAL =0
@#define DTR =0 
@#define CTR =0
@#define PEG =0
@#define ACT =1
@#define ADT =0
@#define ANT =0

 
@#if DTR == 1 
case_title='domestic inflation-based Taylor rule (DTR)'; 
@#else 
@#if ANT == 1 
case_title='Augmentated net exports-based Taylor rule (ANT)'; 
@#else
@#if CTR ==1 
case_title='CPI inflation-based Taylor rule (CTR)'; 
@#else
@#if ACT ==1 
case_title='Augmentated CPI inflation-based Taylor rule (PT)'; 
@#else
@#if ADT ==1 
case_title='Augmentated Domestic inflation-based Taylor rule (PT)'; 
@#else
@#if PEG ==1 
case_title='exchange rate peg (PEG)'; 
@#else 
@#if OPTIMAL ==1 
case_title='Optimal Policy'; 
@#else 
error('One case must be set to 1') 
@#endif 
@#endif 
@#endif 
@#endif 
@#endif 
@#endif 
@#endif 


var pht phn pdt nx sna ena sg eg og nxg pd yg yna rna at aht ahn e pt pn pi yf s x i pf y;


varexo yf_ aht_ ahn_ pf_ ;        
                                      // aht_ = tradable productivity shocks
								      // ahn_ = non-tradable productivity shocks								  
                                      // yf_ = foreign output shocks
                                      // pf_ = foreign price shocks
									
									 

parameters taynx sigaht sigahn lamda nu rhoaht rhoahn tayp tayy sigma alpha omega eta beta epsilon rho phi rhoyf rhopf theta;

taynx = 0.125;
sigaht = 0.0242;
sigahn = 0.0169;

nu = 0.8;
beta = 0.99;
sigma = 0.58;
alpha = 0.3/0.58;
lamda = 1 - alpha;
omega = 0.74;
eta = 1.5;
rho = 1;
epsilon = 6;
theta = 0.75;
phi = 3;

rhoaht = 0.61;
rhoahn = 0.52;
rhoyf = 0.89;
rhopf = 0.86;

tayp = 1.5;
tayy=0.125;



model(linear);

// net exports
nx = sigma*alpha*(eta - 1 + alpha*(omega*(1 - sigma) + sigma) + lamda*eta - 1)*s - sigma*alpha*(1-sigma)*(omega-1)*e;

// IS equation
yg = yg(+1) - (nx(+1) - nx) - (i - sigma*pt(+1) - (1-sigma)*pn(+1) - rna);

// Natural Level of Output
yna = ((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))/
(1+phi*(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))))*(1+phi)*at + 
((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))/(1+phi*(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + 
(sigma*alpha*(eta+lamda*(eta-omega))))))*((1-(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega)))))/(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) 
+ (sigma*alpha*(eta+lamda*(eta-omega)))))*yf - ((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + 
(sigma*alpha*(eta+lamda*(eta-omega))))/(1+phi*(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))))*(((((sigma*alpha*(omega-1))+1)*(1-sigma))-
(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + 
(sigma*alpha*(eta+lamda*(eta-omega))))*(1-sigma))/(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega)))))*ena;

// Natural Level of Terms of Trade
sna = (1/(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega)))))*(yna - yf + (((sigma*alpha*(omega-1))+1)*(1-sigma))*ena);

// Natural Level of Relative Price
ena = aht - ahn;

// Definition of outout gap
yg = y - yna;

// Definition of relative price gap
eg = e - ena;

// Definition of terms of trade gap
sg = s - sna;

// Definition of open economy gap
og = sg - (1-sigma)*eg;

// Definition of net exports gap
nxg = yg - og;

// Nature Rate of Interest Rate 
rna = ((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))/(1+phi*(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + 
(sigma*alpha*(eta+lamda*(eta-omega))))))*(((((sigma*alpha*(omega-1))+1)*(1-sigma)) - (((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))*(1+(phi*sigma)))/(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha)
 + (sigma*alpha*(eta+lamda*(eta-omega)))))*aht*(1 - rhoaht) - 
((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))/(1+phi*(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + 
(sigma*alpha*(eta+lamda*(eta-omega))))))*(((((sigma*alpha*(omega-1))+1)*(1-sigma))+(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))*phi*(1-sigma))/(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega)))))*ahn*(1-rhoahn) - 
((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + 
(sigma*alpha*(eta+lamda*(eta-omega))))/(1+phi*(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))))*((1-(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + 
(sigma*alpha*(eta+lamda*(eta-omega)))))/(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega)))))*yf*(1 - rhoyf);

// Domestic Tradable New Keynesian Philips Curve
pt   = ((1-beta*theta)*(1-theta)/theta)*(phi*yg + sg) + beta*pt(+1); 

// Definition of Tradable Inflation
pt = pht - pht(-1);

// Domestic Non-Tradable New Keynesian Philips Curve              
pn   = ((1-beta*theta)*(1-theta)/theta)*(phi*yg + sg - eg) + beta*pn(+1);

// Definition of Non-Tradable Inflation
pn = phn - phn(-1);                 

// CPI inflation
pi   = beta*pi(+1) + ((1-beta*theta)*(1-theta)/theta)*((1+phi)*yg - nxg) - sigma*alpha*(beta*(s(+1) - s) - (s-s(-1)));                      

// Definition of Terms of Trade
s = s(-1) + x - x(-1) + pf - pt;                                             

// Exogenous Process of Foreign Output
yf   = rhoyf*yf(-1) + yf_; 

// Exogenous Process of Foreign Inflation  
pf   = rhopf*pf(-1) + pf_;   

// Exogenous Process of Tradable Productivity                                                    
aht = rhoaht*aht(-1) + aht_;    

// Exogenous Process of Non-Tradable Productivity                                                       
ahn = rhoahn*ahn(-1) + ahn_;                                                          
 

@#if DTR == 1 
i= tayp*(sigma*pt + (1-sigma)*pn); // domestic inflation-based Taylor rule (DTR) 
@#else 
@#if CTR ==1 
i =tayp*pi; // CPI inflation-based Taylor rule (CTR) 
@#else 
@#if PEG ==1 
x=0; //exchange rate peg (PEG) 
@#else 
@#if OPTIMAL ==1 
pdt - ((1-sqrt(1-4*beta*(((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))/((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))*(1+phi) + epsilon*(((1-beta*theta)*(1-theta)/theta))*(phi*(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega)))) + 1)))^(2))))/(2*((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))/((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))*(1+phi) + epsilon*(((1-beta*theta)*(1-theta)/theta))*(phi*(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega)))) + 1)))*beta))*pdt(-1) + (((1-sqrt(1-4*beta*(((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))/((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))*(1+phi) + epsilon*(((1-beta*theta)*(1-theta)/theta))*(phi*(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega)))) + 1)))^(2))))/(2*((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))/((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))*(1+phi) + epsilon*(((1-beta*theta)*(1-theta)/theta))*(phi*(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega)))) + 1)))*beta))*(((1-beta*theta)*(1-theta)/theta))/(1-((1-sqrt(1-4*beta*(((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))/((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))*(1+phi) + epsilon*(((1-beta*theta)*(1-theta)/theta))*(phi*(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega)))) + 1)))^(2))))/(2*((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))/((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))*(1+phi) + epsilon*(((1-beta*theta)*(1-theta)/theta))*(phi*(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega)))) + 1)))*beta))*beta))*nxg = 0;
@#else
@#if ACT ==1 
i = nu*i(-1) + (1-nu)*tayp*pi;  
@#else
@#if ADT ==1 
i = nu*i(-1) + (1-nu)*tayp*(sigma*pt + (1-sigma)*pn);  
@#else
@#if ANT ==1 
i = nu*i(-1) + (1-nu)*(tayp*(sigma*pt + (1-sigma)*pn) - taynx*nx);  
@#else
@#endif 
@#endif 
@#endif 
@#endif
@#endif 
@#endif  
@#endif   
                                                                     

// Market Clearing Condition
y = yf + (((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))*s - (((sigma*alpha*(omega-1))+1)*(1-sigma))*e;                                                                          

// Definition of Relative Home Producer Price
e = e(-1) - pt + pn;                                                                                                 

// Definition of Composite Domestic Inflation                   
pd = sigma*pt + (1-sigma)*pn;

// Definition of Domestic Inflation
pd = pdt - pdt(-1);

// Aggregate Productivity 
at = sigma*aht + (1 - sigma)*ahn;                                                         
end;


steady;
check;

///////////////////////////////////////////////////////////////////////////////////////////////////////

sigaht = 0.005;
sigahn = 0.005;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');


stoch_simul(order=1, irf=0, noprint);

V(1,1)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.005;
sigahn = 0.007;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');



stoch_simul(order=1, irf=0, noprint);

V(2,1)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.005;
sigahn = 0.009;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(3,1)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.005;
sigahn = 0.011;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(4,1)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.005;
sigahn = 0.013;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(5,1)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.005;
sigahn = 0.015;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(6,1)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.005;
sigahn = 0.017;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(7,1)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.005;
sigahn = 0.019;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(8,1)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.005;
sigahn = 0.021;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(9,1)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.005;
sigahn = 0.023;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(10,1)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.005;
sigahn = 0.025;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(11,1)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

//////////////////////////////////////////////////////////////////////////////////////////////////////


sigaht = 0.007;
sigahn = 0.005;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(1,2)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.007;
sigahn = 0.007;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(2,2)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.007;
sigahn = 0.009;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(3,2)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.007;
sigahn = 0.011;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(4,2)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.007;
sigahn = 0.013;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(5,2)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.007;
sigahn = 0.015;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(6,2)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.007;
sigahn = 0.017;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(7,2)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.007;
sigahn = 0.019;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(8,2)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.007;
sigahn = 0.021;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(9,2)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.007;
sigahn = 0.023;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(10,2)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.007;
sigahn = 0.025;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(11,2)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

////////////////////////////////////////////////////////////////////////////////////////////

sigaht = 0.009;
sigahn = 0.005;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(1,3)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.009;
sigahn = 0.007;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(2,3)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.009;
sigahn = 0.009;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(3,3)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.009;
sigahn = 0.011;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(4,3)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.009;
sigahn = 0.013;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(5,3)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.009;
sigahn = 0.015;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(6,3)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.009;
sigahn = 0.017;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(7,3)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.009;
sigahn = 0.019;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(8,3)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.009;
sigahn = 0.021;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(9,3)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.009;
sigahn = 0.023;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(10,3)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.009;
sigahn = 0.025;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(11,3)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

///////////////////////////////////////////////////////////////////////////////

sigaht = 0.011;
sigahn = 0.005;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(1,4)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.011;
sigahn = 0.007;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(2,4)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.011;
sigahn = 0.009;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(3,4)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.011;
sigahn = 0.011;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(4,4)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.011;
sigahn = 0.013;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(5,4)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.011;
sigahn = 0.015;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(6,4)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.011;
sigahn = 0.017;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(7,4)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.011;
sigahn = 0.019;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(8,4)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.011;
sigahn = 0.021;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(9,4)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.011;
sigahn = 0.023;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(10,4)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.011;
sigahn = 0.025;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(11,4)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

////////////////////////////////////////////////////////////////////////

sigaht = 0.013;
sigahn = 0.005;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(1,5)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.013;
sigahn = 0.007;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(2,5)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.013;
sigahn = 0.009;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(3,5)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.013;
sigahn = 0.011;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(4,5)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.013;
sigahn = 0.013;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(5,5)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.013;
sigahn = 0.015;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(6,5)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.013;
sigahn = 0.017;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(7,5)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.013;
sigahn = 0.019;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(8,5)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.013;
sigahn = 0.021;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(9,5)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.013;
sigahn = 0.023;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(10,5)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.013;
sigahn = 0.025;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(11,5)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

///////////////////////////////////////////////////////////////////////////

sigaht = 0.015;
sigahn = 0.005;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(1,6)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.015;
sigahn = 0.007;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(2,6)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.015;
sigahn = 0.009;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(3,6)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.015;
sigahn = 0.011;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(4,6)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.015;
sigahn = 0.013;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(5,6)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.015;
sigahn = 0.015;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(6,6)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.015;
sigahn = 0.017;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(7,6)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.015;
sigahn = 0.019;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(8,6)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.015;
sigahn = 0.021;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(9,6)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.015;
sigahn = 0.023;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(10,6)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.015;
sigahn = 0.025;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(11,6)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

///////////////////////////////////////////////////////////////////

sigaht = 0.017;
sigahn = 0.005;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(1,7)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.017;
sigahn = 0.007;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(2,7)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.017;
sigahn = 0.009;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(3,7)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.017;
sigahn = 0.011;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(4,7)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.017;
sigahn = 0.013;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(5,7)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.017;
sigahn = 0.015;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(6,7)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.017;
sigahn = 0.017;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(7,7)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.017;
sigahn = 0.019;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(8,7)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.017;
sigahn = 0.021;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(9,7)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.017;
sigahn = 0.023;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(10,7)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.017;
sigahn = 0.025;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(11,7)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

////////////////////////////////////////////////////////////////

sigaht = 0.019;
sigahn = 0.005;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(1,8)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.019;
sigahn = 0.007;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(2,8)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.019;
sigahn = 0.009;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(3,8)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.019;
sigahn = 0.011;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(4,8)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.019;
sigahn = 0.013;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(5,8)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.019;
sigahn = 0.015;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(6,8)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.019;
sigahn = 0.017;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(7,8)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.019;
sigahn = 0.019;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(8,8)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.019;
sigahn = 0.021;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(9,8)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.019;
sigahn = 0.023;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(10,8)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.019;
sigahn = 0.025;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(11,8)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

///////////////////////////////////////////////////////////////////////

sigaht = 0.021;
sigahn = 0.005;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(1,9)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.021;
sigahn = 0.007;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(2,9)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.021;
sigahn = 0.009;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(3,9)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.021;
sigahn = 0.011;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(4,9)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.021;
sigahn = 0.013;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(5,9)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.021;
sigahn = 0.015;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(6,9)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.021;
sigahn = 0.017;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(7,9)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.021;
sigahn = 0.019;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(8,9)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.021;
sigahn = 0.021;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(9,9)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.021;
sigahn = 0.023;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(10,9)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.021;
sigahn = 0.025;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(11,9)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

////////////////////////////////////////////////////////

sigaht = 0.023;
sigahn = 0.005;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(1,10)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.023;
sigahn = 0.007;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(2,10)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.023;
sigahn = 0.009;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(3,10)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.023;
sigahn = 0.011;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(4,10)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.023;
sigahn = 0.013;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(5,10)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.023;
sigahn = 0.015;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(6,10)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.023;
sigahn = 0.017;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(7,10)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.023;
sigahn = 0.019;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(8,10)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.023;
sigahn = 0.021;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(9,10)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.023;
sigahn = 0.023;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(10,10)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.023;
sigahn = 0.025;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(11,10)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

/////////////////////////////////////////////////////////////////////////////

sigaht = 0.025;
sigahn = 0.005;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(1,11)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.025;
sigahn = 0.007;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(2,11)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.025;
sigahn = 0.009;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(3,11)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

sigaht = 0.025;
sigahn = 0.011;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(4,11)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.025;
sigahn = 0.013;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(5,11)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.025;
sigahn = 0.015;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(6,11)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.025;
sigahn = 0.017;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(7,11)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.025;
sigahn = 0.019;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(8,11)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.025;
sigahn = 0.021;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(9,11)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.025;
sigahn = 0.023;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(10,11)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;
sigaht = 0.025;
sigahn = 0.025;

shocks;  
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;
var yf_; stderr 0.0054;

corr aht_, ahn_ = 0.5287;
corr aht_, yf_ = 0.4758;
corr ahn_, yf_ = 0.2318;
end;

stoch_simul(order=1, irf=0, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'yg', 'pd', 'pi', 'og'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');

stoch_simul(order=1, irf=0, noprint);

V(11,11)= (((1-sigma*alpha)/((1+(sigma*alpha*(omega-1)))*(1-sigma*alpha)+(sigma*alpha*(eta+lamda*(eta-omega)))))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;
end;

@#if DTR == 1
save('J_DTR','V','cyc_moments','M_','oo_','options_','case_title');
@#else
@#if CTR ==1
save('J_CTR','V','cyc_moments','M_','oo_','options_','case_title');
@#else
@#if PEG ==1
save('J_PEG','V','M_','cyc_moments','oo_','options_','case_title');
@#else
@#if OPTIMAL ==1
save('J_OPTIMAL','V','M_','cyc_moments','oo_','options_','case_title');
@#else
@#if ACT ==1
save('J_ACT','V','M_','cyc_moments','oo_','options_','case_title');
@#else
@#if ADT ==1
save('J_ADT','V','M_','cyc_moments','oo_','options_','case_title');
@#else
@#if ANT ==1
save('J_ANT','V','M_','cyc_moments','oo_','options_','case_title');
@#else
error('Undefined case')
@#endif
@#endif
@#endif
@#endif
@#endif
@#endif
@#endif



    DTR=load('J_DTR.mat'); 
    CTR=load('J_CTR.mat');
    PEG=load('J_PEG.mat');
    OPTIMAL=load('J_OPTIMAL.mat');
    ACT=load('J_ACT.mat'); 
    ADT=load('J_ADT.mat');
    ANT=load('J_ANT.mat');


case_string={'sigaht = 0.005', 'sigaht = 0.007','sigaht = 0.009','sigaht = 0.011','sigaht = 0.013','sigaht = 0.015','sigaht = 0.017','sigaht = 0.019','sigaht = 0.021','sigaht = 0.023','sigaht = 0.025'};
    fprintf('\nTABLE 2: Contribution to welfare losses\n')
    fprintf('%20s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s  \t %6s \n','','OPTIMAL','DTR','CTR','ADT','ANT','ACT','PEG')
    for case_iter=1:11
        fprintf('%-s \n',case_string{case_iter});
        fprintf('%-20s \t %5.4f \t %5.4f \t %5.4f \t %5.4f \t %5.4f \t %5.4f \t %5.4f \n\n','Total',OPTIMAL.V(1,case_iter),DTR.V(1,case_iter),CTR.V(1,case_iter),ADT.V(1,case_iter),ANT.V(1,case_iter),ACT.V(1,case_iter),PEG.V(1,case_iter))
        
end;