function [residual, g1, g2, g3] = wel4_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations.
%                                          Dynare may prepend or append auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g3        [M_.endo_nbr by (M_.endo_nbr)^3] double   Third derivatives matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 27, 1);

%
% Model equations
%

T55 = (1+params(10)*params(11)*(params(12)-1))*(1-params(10)*params(11))+params(10)*params(11)*(params(13)+params(4)*(params(13)-params(12)));
T59 = T55/(1+T55*params(17));
T70 = (1-params(10))*(1+params(10)*params(11)*(params(12)-1));
T74 = T59*(T70-(1-params(10))*T55)/T55;
T80 = 1/T55;
T111 = T59*(T70-T55*(1+params(10)*params(17)))/T55;
T119 = T59*(T70+(1-params(10))*T55*params(17))/T55;
T136 = (1-params(14)*params(20))*(1-params(20))/params(20);
lhs =y(4);
rhs =params(10)*params(11)*(params(13)-1+params(11)*(params(10)+params(12)*(1-params(10)))+params(13)*params(4)-1)*y(23)-params(10)*params(11)*(1-params(10))*(params(12)-1)*y(18);
residual(1)= lhs-rhs;
lhs =y(12);
rhs =y(12)-(y(25)-params(10)*y(19)-(1-params(10))*y(20)-y(14));
residual(2)= lhs-rhs;
lhs =y(13);
rhs =T59*(1+params(17))*y(15)+T59*(1-T55)/T55*y(22)-T74*y(6);
residual(3)= lhs-rhs;
lhs =y(5);
rhs =T80*(y(13)-y(22)+T70*y(6));
residual(4)= lhs-rhs;
lhs =y(6);
rhs =y(16)-y(17);
residual(5)= lhs-rhs;
lhs =y(12);
rhs =y(27)-y(13);
residual(6)= lhs-rhs;
lhs =y(8);
rhs =y(18)-y(6);
residual(7)= lhs-rhs;
lhs =y(7);
rhs =y(23)-y(5);
residual(8)= lhs-rhs;
lhs =y(9);
rhs =y(7)-(1-params(10))*y(8);
residual(9)= lhs-rhs;
lhs =y(10);
rhs =y(12)-y(9);
residual(10)= lhs-rhs;
lhs =y(14);
rhs =y(16)*T111*(1-params(6))-y(17)*T119*(1-params(7))-T59*(1-T55)/T55*y(22)*(1-params(18));
residual(11)= lhs-rhs;
lhs =y(19);
rhs =T136*(y(7)+y(12)*params(17))+y(19)*params(14);
residual(12)= lhs-rhs;
residual(13) = y(19);
lhs =y(20);
rhs =T136*(y(7)+y(12)*params(17)-y(8))+y(20)*params(14);
residual(14)= lhs-rhs;
residual(15) = y(20);
lhs =y(21);
rhs =params(14)*y(21)+T136*(y(12)*(1+params(17))-y(10));
residual(16)= lhs-rhs;
lhs =y(23);
rhs =y(23)+y(24)-y(24)+y(26)-y(19);
residual(17)= lhs-rhs;
lhs =y(22);
rhs =y(22)*params(18)+x(1);
residual(18)= lhs-rhs;
lhs =y(26);
rhs =y(26)*params(19)+x(4);
residual(19)= lhs-rhs;
lhs =y(16);
rhs =y(16)*params(6)+x(2);
residual(20)= lhs-rhs;
lhs =y(17);
rhs =y(17)*params(7)+x(3);
residual(21)= lhs-rhs;
lhs =y(25);
rhs =y(25)*params(5)+y(21)*(1-params(5))*params(8);
residual(22)= lhs-rhs;
lhs =y(27);
rhs =y(22)+y(23)*T55-y(18)*T70;
residual(23)= lhs-rhs;
lhs =y(18);
rhs =y(20)+y(18)-y(19);
residual(24)= lhs-rhs;
lhs =y(11);
rhs =params(10)*y(19)+(1-params(10))*y(20);
residual(25)= lhs-rhs;
residual(26) = y(11);
lhs =y(15);
rhs =params(10)*y(16)+(1-params(10))*y(17);
residual(27)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(27, 27);

  %
  % Jacobian matrix
  %

  g1(1,4)=1;
  g1(1,18)=params(10)*params(11)*(1-params(10))*(params(12)-1);
  g1(1,23)=(-(params(10)*params(11)*(params(13)-1+params(11)*(params(10)+params(12)*(1-params(10)))+params(13)*params(4)-1)));
  g1(2,14)=(-1);
  g1(2,19)=(-params(10));
  g1(2,20)=(-(1-params(10)));
  g1(2,25)=1;
  g1(3,6)=T74;
  g1(3,13)=1;
  g1(3,15)=(-(T59*(1+params(17))));
  g1(3,22)=(-(T59*(1-T55)/T55));
  g1(4,5)=1;
  g1(4,6)=(-(T70*T80));
  g1(4,13)=(-T80);
  g1(4,22)=T80;
  g1(5,6)=1;
  g1(5,16)=(-1);
  g1(5,17)=1;
  g1(6,12)=1;
  g1(6,13)=1;
  g1(6,27)=(-1);
  g1(7,6)=1;
  g1(7,8)=1;
  g1(7,18)=(-1);
  g1(8,5)=1;
  g1(8,7)=1;
  g1(8,23)=(-1);
  g1(9,7)=(-1);
  g1(9,8)=1-params(10);
  g1(9,9)=1;
  g1(10,9)=1;
  g1(10,10)=1;
  g1(10,12)=(-1);
  g1(11,14)=1;
  g1(11,16)=(-(T111*(1-params(6))));
  g1(11,17)=T119*(1-params(7));
  g1(11,22)=T59*(1-T55)/T55*(1-params(18));
  g1(12,7)=(-T136);
  g1(12,12)=(-(params(17)*T136));
  g1(12,19)=1-params(14);
  g1(13,19)=1;
  g1(14,7)=(-T136);
  g1(14,8)=T136;
  g1(14,12)=(-(params(17)*T136));
  g1(14,20)=1-params(14);
  g1(15,20)=1;
  g1(16,10)=T136;
  g1(16,12)=(-((1+params(17))*T136));
  g1(16,21)=1-params(14);
  g1(17,19)=1;
  g1(17,26)=(-1);
  g1(18,22)=1-params(18);
  g1(19,26)=1-params(19);
  g1(20,16)=1-params(6);
  g1(21,17)=1-params(7);
  g1(22,21)=(-((1-params(5))*params(8)));
  g1(22,25)=1-params(5);
  g1(23,18)=T70;
  g1(23,22)=(-1);
  g1(23,23)=(-T55);
  g1(23,27)=1;
  g1(24,19)=1;
  g1(24,20)=(-1);
  g1(25,11)=1;
  g1(25,19)=(-params(10));
  g1(25,20)=(-(1-params(10)));
  g1(26,11)=1;
  g1(27,15)=1;
  g1(27,16)=(-params(10));
  g1(27,17)=(-(1-params(10)));
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],27,729);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],27,19683);
end
end
end
end
