function [residual, g1, g2, g3] = w1_nx_p_lagy_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(27, 1);
T59 = (1+params(10)*params(11)*(params(12)-1))*(1-params(10)*params(11))+params(10)*params(11)*(params(13)+params(4)*(params(13)-params(12)));
T63 = T59/(1+T59*params(17));
T74 = (1-params(10))*(1+params(10)*params(11)*(params(12)-1));
T78 = T63*(T74-(1-params(10))*T59)/T59;
T84 = 1/T59;
T115 = T63*(T74-T59*(1+params(10)*params(17)))/T59;
T123 = T63*(T74+(1-params(10))*T59*params(17))/T59;
T141 = (1-params(14)*params(20))*(1-params(20))/params(20);
lhs =y(16);
rhs =params(10)*params(11)*(params(13)-1+params(11)*(params(10)+params(12)*(1-params(10)))+params(13)*params(4)-1)*y(35)-params(10)*params(11)*(1-params(10))*(params(12)-1)*y(30);
residual(1)= lhs-rhs;
lhs =y(24);
rhs =y(41)-(y(40)-y(16))-(y(37)-params(10)*y(42)-(1-params(10))*y(43)-y(26));
residual(2)= lhs-rhs;
lhs =y(25);
rhs =T63*(1+params(17))*y(27)+T63*(1-T59)/T59*y(34)-T78*y(18);
residual(3)= lhs-rhs;
lhs =y(17);
rhs =T84*(y(25)-y(34)+T74*y(18));
residual(4)= lhs-rhs;
lhs =y(18);
rhs =y(28)-y(29);
residual(5)= lhs-rhs;
lhs =y(24);
rhs =y(39)-y(25);
residual(6)= lhs-rhs;
lhs =y(20);
rhs =y(30)-y(18);
residual(7)= lhs-rhs;
lhs =y(19);
rhs =y(35)-y(17);
residual(8)= lhs-rhs;
lhs =y(21);
rhs =y(19)-(1-params(10))*y(20);
residual(9)= lhs-rhs;
lhs =y(22);
rhs =y(24)-y(21);
residual(10)= lhs-rhs;
lhs =y(26);
rhs =y(28)*T115*(1-params(6))-y(29)*T123*(1-params(7))-T63*(1-T59)/T59*y(34)*(1-params(18));
residual(11)= lhs-rhs;
lhs =y(31);
rhs =T141*(y(19)+y(24)*params(17))+y(42)*params(14);
residual(12)= lhs-rhs;
lhs =y(31);
rhs =y(13)-y(1);
residual(13)= lhs-rhs;
lhs =y(32);
rhs =T141*(y(19)+y(24)*params(17)-y(20))+y(43)*params(14);
residual(14)= lhs-rhs;
lhs =y(32);
rhs =y(14)-y(2);
residual(15)= lhs-rhs;
lhs =y(33);
rhs =params(14)*y(44)+T141*(y(24)*(1+params(17))-y(22))-params(10)*params(11)*(params(14)*(y(45)-y(35))-(y(35)-y(8)));
residual(16)= lhs-rhs;
lhs =y(35);
rhs =y(8)+y(36)-y(9)+y(38)-y(31);
residual(17)= lhs-rhs;
lhs =y(34);
rhs =params(18)*y(7)+x(it_, 1);
residual(18)= lhs-rhs;
lhs =y(38);
rhs =params(19)*y(11)+x(it_, 2);
residual(19)= lhs-rhs;
lhs =y(28);
rhs =params(6)*y(4)+x(it_, 3);
residual(20)= lhs-rhs;
lhs =y(29);
rhs =params(7)*y(5)+x(it_, 4);
residual(21)= lhs-rhs;
lhs =y(37);
rhs =params(5)*y(10)+(1-params(5))*(params(8)*(params(10)*y(31)+(1-params(10))*y(32))-y(16)*params(1)+params(9)*(y(39)-y(12)));
residual(22)= lhs-rhs;
lhs =y(39);
rhs =y(34)+y(35)*T59-y(30)*T74;
residual(23)= lhs-rhs;
lhs =y(30);
rhs =y(32)+y(6)-y(31);
residual(24)= lhs-rhs;
lhs =y(23);
rhs =params(10)*y(31)+(1-params(10))*y(32);
residual(25)= lhs-rhs;
lhs =y(23);
rhs =y(15)-y(3);
residual(26)= lhs-rhs;
lhs =y(27);
rhs =params(10)*y(28)+(1-params(10))*y(29);
residual(27)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(27, 49);

  %
  % Jacobian matrix
  %

  g1(1,16)=1;
  g1(1,30)=params(10)*params(11)*(1-params(10))*(params(12)-1);
  g1(1,35)=(-(params(10)*params(11)*(params(13)-1+params(11)*(params(10)+params(12)*(1-params(10)))+params(13)*params(4)-1)));
  g1(2,16)=(-1);
  g1(2,40)=1;
  g1(2,24)=1;
  g1(2,41)=(-1);
  g1(2,26)=(-1);
  g1(2,42)=(-params(10));
  g1(2,43)=(-(1-params(10)));
  g1(2,37)=1;
  g1(3,18)=T78;
  g1(3,25)=1;
  g1(3,27)=(-(T63*(1+params(17))));
  g1(3,34)=(-(T63*(1-T59)/T59));
  g1(4,17)=1;
  g1(4,18)=(-(T74*T84));
  g1(4,25)=(-T84);
  g1(4,34)=T84;
  g1(5,18)=1;
  g1(5,28)=(-1);
  g1(5,29)=1;
  g1(6,24)=1;
  g1(6,25)=1;
  g1(6,39)=(-1);
  g1(7,18)=1;
  g1(7,20)=1;
  g1(7,30)=(-1);
  g1(8,17)=1;
  g1(8,19)=1;
  g1(8,35)=(-1);
  g1(9,19)=(-1);
  g1(9,20)=1-params(10);
  g1(9,21)=1;
  g1(10,21)=1;
  g1(10,22)=1;
  g1(10,24)=(-1);
  g1(11,26)=1;
  g1(11,28)=(-(T115*(1-params(6))));
  g1(11,29)=T123*(1-params(7));
  g1(11,34)=T63*(1-T59)/T59*(1-params(18));
  g1(12,19)=(-T141);
  g1(12,24)=(-(params(17)*T141));
  g1(12,31)=1;
  g1(12,42)=(-params(14));
  g1(13,1)=1;
  g1(13,13)=(-1);
  g1(13,31)=1;
  g1(14,19)=(-T141);
  g1(14,20)=T141;
  g1(14,24)=(-(params(17)*T141));
  g1(14,32)=1;
  g1(14,43)=(-params(14));
  g1(15,2)=1;
  g1(15,14)=(-1);
  g1(15,32)=1;
  g1(16,22)=T141;
  g1(16,24)=(-((1+params(17))*T141));
  g1(16,33)=1;
  g1(16,44)=(-params(14));
  g1(16,8)=params(10)*params(11);
  g1(16,35)=params(10)*params(11)*((-params(14))-1);
  g1(16,45)=params(10)*params(11)*params(14);
  g1(17,31)=1;
  g1(17,8)=(-1);
  g1(17,35)=1;
  g1(17,9)=1;
  g1(17,36)=(-1);
  g1(17,38)=(-1);
  g1(18,7)=(-params(18));
  g1(18,34)=1;
  g1(18,46)=(-1);
  g1(19,11)=(-params(19));
  g1(19,38)=1;
  g1(19,47)=(-1);
  g1(20,4)=(-params(6));
  g1(20,28)=1;
  g1(20,48)=(-1);
  g1(21,5)=(-params(7));
  g1(21,29)=1;
  g1(21,49)=(-1);
  g1(22,16)=(-((1-params(5))*(-params(1))));
  g1(22,31)=(-((1-params(5))*params(10)*params(8)));
  g1(22,32)=(-((1-params(5))*(1-params(10))*params(8)));
  g1(22,10)=(-params(5));
  g1(22,37)=1;
  g1(22,12)=(-((1-params(5))*(-params(9))));
  g1(22,39)=(-((1-params(5))*params(9)));
  g1(23,30)=T74;
  g1(23,34)=(-1);
  g1(23,35)=(-T59);
  g1(23,39)=1;
  g1(24,6)=(-1);
  g1(24,30)=1;
  g1(24,31)=1;
  g1(24,32)=(-1);
  g1(25,23)=1;
  g1(25,31)=(-params(10));
  g1(25,32)=(-(1-params(10)));
  g1(26,3)=1;
  g1(26,15)=(-1);
  g1(26,23)=1;
  g1(27,27)=1;
  g1(27,28)=(-params(10));
  g1(27,29)=(-(1-params(10)));

if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],27,2401);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],27,117649);
end
end
end
end
