// Monetary Policy and Net Exports Externalities in the Small Open Economy (Jae Hun Shim)

@#define OPTIMAL =1
@#define ANT =0
@#define CTR =0
@#define PEG =0


@#if ANT == 1 
case_title='Augmentated net exports-based Taylor rule (ANT)'; 
@#else
@#if CTR ==1 
case_title='CPI inflation-based Taylor rule (CTR)'; 
@#else 
@#if OPTIMAL ==1 
case_title='Optimal Policy'; 
@#else 
@#if PEG ==1 
case_title='exchange rate peg (PEG)'; 
@#else 
error('One case must be set to 1') 
@#endif 
@#endif 
@#endif 
@#endif 


var 
yg nxg $nxg$ (long_name='Net Exports Gap')
yna rpg $rpg$ (long_name='Relative Price Gap') sna ena eg sg og
pdt pd $pd$ (long_name='Domestic Inflation') pff chn e $e$ (long_name='Relative Price of Goods') nx $nx$ (long_name='Net Exports') v chni pii pt $pt$ (long_name='TS Inflation') pn $pn$ (long_name='NTS Inflation') mcht mchn pht phn pi $pi$ (long_name='CPI Inflation') p yf s $s$ (long_name='Terms of Trade') x i $i$ (long_name='Interest Rate') if ahn aht q $q$ (long_name='Real Exchange Rate') cht chft cft y $y$ (long_name='Output') yht $yht$ (long_name='TS Output') c$c$ (long_name='Consumption') nht nhn n $n$ (long_name='Employment') w yhn $yhn$ (long_name='NTS Output') rw $rw$ (long_name='Real Wage') 
pti mchti phti nhti mchni phni nhni yhti $yhti$ (long_name='TIS Output') yhni $yhni$ (long_name='NTIS Output') si $si$ (long_name='Terms of Trade in IS') chti chfti cfti ptti pnni yi yio $yio$ (long_name='IS Output');

varexo yf_ aht_ ahn_  if_  pff_ ;     

parameters taynx sigaht sigahn
tao zv etai wai phii mu kappa del vi lamda
nu alphai omegai xi btheta tayp tayy yiyss  nhtyss nhnyss nhtiyss nhniyss nyss nhtnss nhnnss nhtinss nhninss sigma sigmai alpha omega eta beta theta rho phi rhoaht rhoahn rhoyf rhopf rhoif delta upsilon;

taynx = 0.125;
sigaht = 0.0242;
sigahn = 0.0169;

beta = 0.99;
sigma = 0.58;
alpha = 0.17;
nu = 0.8;
omega = 0.74;
eta = 1.5;
theta = 6;
sigmai = 0.74;

etai = 3.14;
omegai = 0.001;
alphai = 0.54;
delta = 0.75;  // denoted with theta with other model parameters
rho = 1;
phi = 3;


rhoaht = 0.61;
rhoahn = 0.52;
rhoyf = 0.89;


rhopf = 0.86;
rhoif = 0.86;
tayp = 1.5;
tayy=0.125;

xi = sigma*alpha*(eta - 1 + alpha*(omega*(1-sigma) + (1/rho)*sigma) + (1-alpha)*eta - (1/rho));
btheta = sigma*alpha*(1-sigma)*(omega - (1/rho));

lamda = 1 - alpha;
wai = sigma*alpha*(omega-1);
phii = sigma*alpha*(eta+lamda*(eta-omega));
mu = (wai+1)*(1-sigma*alpha) + phii;
vi = (1-beta*delta)*(1-delta)/delta;
tao = (wai+1)*(1-sigma);
kappa = mu/(mu*(1+phi) + epsilon*vi*(phi*mu + 1));
del = (1-sqrt(1-4*beta*(kappa^(2))))/(2*kappa*beta);
zv = mu/(1+phi*mu);

upsilon = 0.86;
nhtyss=(1-upsilon)*sigma;
yiyss=upsilon*sigma;
nhnyss = 1- sigma ; 
nhtiyss = (1-alphai)*sigmai*yiyss;
nhniyss = (1-sigmai)*yiyss;
nyss = nhtyss + nhnyss + nhtiyss + nhniyss;
nhtnss = (nhtyss/nyss);
nhnnss = (nhnyss/nyss);
nhtinss = (nhtiyss/nyss);
nhninss = (nhniyss/nyss);

model(linear);

// risk sharing condition
c    = yf + (1/rho)*q; 

// labour supply                                                           
w - p = rho*c + phi*n;    

// domestic tradable inflation
pt   = (1 - delta)*(1 - delta*beta)*mcht*delta^(-1) + beta*pt(+1);  

// domestic non-tradable inflation              
pn   = (1 - delta)*(1 - delta*beta)*mchn*delta^(-1) + beta*pn(+1);  

// CPI Inflation          
pi   = sigma*pt + (1 - sigma)*pn + sigma*alpha*(s-s(-1)); 

// definition of domestic tradable inflation                        
pt   = pht - pht(-1); 

// def. of domestic non-tradable inflation                                                        
pn   = phn - phn(-1);                                                              

// marginal cost of home tradable goods
mcht = (1-upsilon)*w - pht - aht + upsilon*pti;  

// marginal cost of home non-tradable goods                                 
mchn = w - phn - ahn;                                               

// definition of the terms of trade
s    = x + pff - pht;                                               

// Uncovered Interest Parity Condition
i    = if + x(+1) - x;                                                            

// definition of the real exchange rate
q = x + pff - p;

// relative prices
rpg = sg - (1-sigma)*eg;

// exogenous process of foreign output
yf   = rhoyf*yf(-1) + yf_; 

// exogenous process of foreign interest rate                                                       
if   = rhoif*if(-1) + if_;   

// exogenous process of home tradable good productivity                                                   
aht  = rhoaht*aht(-1) + aht_;

// exogenous process of non-tradable good productivity                                                      
ahn  = rhoahn*ahn(-1) + ahn_; 

// exogenous process of foreign price                                                     
pff  = rhopf*pff(-1) + pff_;                                                       

// demand for the home tradable goods from home consumers
cht  = s*(eta*alpha + omega*(1-alpha)) - omega*q + c;  

// demand for the home tradable goods from foreigner(exports)                                                       
chft  = eta*s + yf; 

// demand for the home non-tradable goods                                                                                        
chn  = omega*(p - phn)+ c;  

// demand for imports                                                                                  
cft = (omega-(1/rho))*(1-sigma)*(phn-pht) - (alpha*(omega*(1-sigma) + (1/rho)*sigma) + (1-alpha)*eta - (1/rho))*s + yf;

// non-tradable goods clearing condition
chn = yhn;

// home tradable goods clearing condition
yht  = cht*(1-alpha) + chft*alpha;                                                                            

@#if PEG ==1 
x=0; //exchange rate peg (PEG) 
@#else 
@#if CTR ==1 
i =tayp*pi; // CPI inflation-based Taylor rule (CTR) 
@#else
@#if OPTIMAL ==1 
pdt - del*pdt(-1) + (del*vi/(1-del*beta))*nxg = 0;
@#else
@#if ANT ==1 
i = nu*i(-1) + (1-nu)*(tayp*(sigma*pt + (1-sigma)*pn) - taynx*nx);  
@#else
@#endif 
@#endif 
@#endif 
@#endif

// Natural Level of Output
//yna = zv*(1+phi)*at + zv*((1-mu)/mu)*yf - zv*((tao-mu*(1-sigma))/mu)*ena;
yna = zv*(1+phi)*(sigma*aht + (1-sigma)*ahn) + zv*((1-mu)/mu)*yf - zv*((tao-mu*(1-sigma))/mu)*ena;

// Natural Level of Terms of Trade
sna = (1/mu)*(yna - yf + tao*ena);

// Natural Level of Relative Price
ena = aht - ahn;

// Definition of relative price gap
eg = e - ena;

// Definition of terms of trade gap
sg = s - sna;

// Definition of open economy gap
og = sg - (1-sigma)*eg;

// Definition of outout gap
yg = y - yna;

// Definition of net exports gap
nxg = yg - og;

// goods market clearing condition
y = sigma*(1-alpha)*cht + sigma*alpha*chft + (1-sigma)*chn;

// consumption clearing condition
c = sigma*(1-alpha)*cht + sigma*alpha*cft + (1-sigma)*chn;

// definition of composite domestic inflation
pd = sigma*pt + (1-sigma)*pn;

// Definition of Domestic Inflation
pd = pdt - pdt(-1);

// home tradable goods production function
yht   = aht + (1-upsilon)*nht + upsilon*yi; 

// home non-tradable goods production function                                                                   
yhn   = ahn + nhn;                                                                                  

// definition of real wage
w - p = rw;                                                                                                     

// definition of relative price of non-tradable and tradable goods
e = phn - pht; 

// definition of net exports                                                                                                
nx = xi*s - btheta*e;                                                                                           

// definition of real value of home production
v = c + nx;                                                                                                     

// labour market clearing condition
n= nhtnss*nht + nhnnss*nhn + nhtinss*nhti + nhninss*nhni;


// intermediate input sector

// demand for the home tradable inputs from home consumers
chti  = alphai*si*(etai-omegai) + (pti - phti) + yi;  

// demand for the home tradable inputs from foreigner(exports)                                                           
chfti  = etai*si + yf; 

// demand for the home non-tradable inputs                                                                                         
chni  = omegai*(pti - phni)+ yi;   

// demand for foreign tradable inputs (imports)                                                                             
cfti  = si*((1-alphai)*omegai*(1-sigmai)-omegai*(1-sigmai)-(1-alphai)*etai)- omegai*(1-sigmai)*(phni-phti)+yi;   

// home inputs clearing condition   
yhti  = chti*(1-alphai) + chfti*alphai;                                                                          

// domestic tradable inputs inflation
ptti   = (1 - delta)*(1 - delta*beta)*mchti*delta^(-1) + beta*ptti(+1);

// domestic non-tradable inputs inflation                 
pnni   = (1 - delta)*(1 - delta*beta)*mchni*delta^(-1) + beta*pnni(+1);                 

// definition of domestic tradable input inflation
ptti   = phti - phti(-1);  

// definition of domestic non-tradable input inflation                                                             
pnni   = phni - phni(-1);                                                               

// marginal cost of home tradable inputs
mchti = w - phti - aht;  

// marginal cost of home non-tradable inputs                                          
mchni = w - phni - ahn;                                            

// definition of the terms of trade for inputs
si    = x + pff - phti;                                           

// home tradable inputs production function
yhti   = aht + nhti;  

// home non-tradable inputs production function                                                                              
yhni   = ahn + nhni;                                                                                

// optimal intermediate and employment decision
yi   = w + nht - pti; 
  
// non-tradable goods market clearing condition                                                                                   
chni = yhni;

// intermediate input sector market clearing condition
yio = (1-alphai)*sigmai*chti + sigmai*alphai*chfti + (1-sigmai)*chni;                                            

// intermediate sector inflation
pii   = sigmai*ptti + (1 - sigmai)*pnni + sigmai*alphai*(si-si(-1));                          

// intermediate input demand clearing condition
yi = (1-alphai)*sigmai*chti + sigmai*alphai*cfti + (1-sigmai)*chni;
                 
end;

steady;
check;

shocks;
var aht_ = sigaht^2; //the standard deviation of productivity
var ahn_= sigahn^2;                                  
end;

stoch_simul(linear, irf=20) y yht yhn c pi pd pt pn q s e rpg nx nxg i rw n yi yio yhti yhni si;


@#if CTR ==1
save('J_CTR','M_','oo_','options_','case_title');
@#else
@#if OPTIMAL ==1
save('J_OPTIMAL','M_','oo_','options_','case_title');
@#else
@#if ANT ==1
save('J_ANT','M_','oo_','options_','case_title');
@#else
@#if PEG ==1
save('J_PEG','M_','oo_','options_','case_title');
@#else
error('Undefined case')
@#endif
@#endif
@#endif
@#endif

    CTR=load('J_CTR.mat');
    OPTIMAL=load('J_OPTIMAL.mat');
    ANT=load('J_ANT.mat');
    PEG=load('J_PEG.mat');


var_string={'y','yht','yhn', 'c', 'pi', 'pd', 'pt', 'pn', 'q', 's', 'e', 'nx', 'rpg', 'i', 'rw', 'n', 'yio', 'yhti', 'yhni', 'si'};
    figure
    for fig_iter=1:length(var_string)
        subplot(5,4,fig_iter)
        plot(1:20,OPTIMAL.oo_.irfs.([var_string{fig_iter},'_aht_']),'b-',1:20,CTR.oo_.irfs.([var_string{fig_iter},'_aht_']),'r',1:20,ANT.oo_.irfs.([var_string{fig_iter},'_aht_']),'k-',1:20,PEG.oo_.irfs.([var_string{fig_iter},'_aht_']),'c' )
        grid on
        title(OPTIMAL.M_.endo_names_long(strmatch(var_string{fig_iter},OPTIMAL.M_.endo_names,'exact'),:))

end;

var_string={'y','yht','yhn', 'c', 'pi', 'pd', 'pt', 'pn', 'q', 's', 'e', 'nx', 'rpg', 'i', 'rw', 'n', 'yio', 'yhti', 'yhni', 'si'};
    figure
    for fig_iter=1:length(var_string)
        subplot(5,4,fig_iter)
        plot(1:20,OPTIMAL.oo_.irfs.([var_string{fig_iter},'_ahn_']),'b-',1:20,CTR.oo_.irfs.([var_string{fig_iter},'_ahn_']),'r',1:20,ANT.oo_.irfs.([var_string{fig_iter},'_ahn_']),'k-',1:20,PEG.oo_.irfs.([var_string{fig_iter},'_ahn_']),'c' )
        grid on
        title(OPTIMAL.M_.endo_names_long(strmatch(var_string{fig_iter},OPTIMAL.M_.endo_names,'exact'),:))
end;

