function [residual, g1, g2, g3] = tn7_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(63, 1);
T3 = (-1);
T11 = 1/params(38);
T34 = params(45)^T3;
T215 = 1/params(9);
lhs =y(52);
rhs =y(39)+T11*y(46);
residual(1)= lhs-rhs;
lhs =y(56)-y(38);
rhs =y(52)*params(38)+params(39)*y(55);
residual(2)= lhs-rhs;
lhs =y(31);
rhs =(1-params(45))*(1-params(45)*params(36))*y(33)*T34+params(36)*y(76);
residual(3)= lhs-rhs;
lhs =y(32);
rhs =T34*(1-params(45))*(1-params(45)*params(36))*y(34)+params(36)*y(77);
residual(4)= lhs-rhs;
lhs =y(37);
rhs =y(31)*params(31)+y(32)*(1-params(31))+params(31)*params(33)*(y(40)-y(6));
residual(5)= lhs-rhs;
lhs =y(31);
rhs =y(35)-y(3);
residual(6)= lhs-rhs;
lhs =y(32);
rhs =y(36)-y(4);
residual(7)= lhs-rhs;
lhs =y(33);
rhs =y(56)*(1-params(46))-y(35)-y(45)+params(46)*y(59);
residual(8)= lhs-rhs;
lhs =y(34);
rhs =y(56)-y(36)-y(44);
residual(9)= lhs-rhs;
lhs =y(40);
rhs =y(41)+y(24)-y(35);
residual(10)= lhs-rhs;
lhs =y(42);
rhs =y(43)+y(78)-y(41);
residual(11)= lhs-rhs;
lhs =y(46);
rhs =y(41)+y(24)-y(38);
residual(12)= lhs-rhs;
lhs =y(16);
rhs =y(20)-(1-params(31))*y(19);
residual(13)= lhs-rhs;
lhs =y(39);
rhs =params(42)*y(5)+x(it_, 1);
residual(14)= lhs-rhs;
lhs =y(43);
rhs =params(44)*y(7)+x(it_, 4);
residual(15)= lhs-rhs;
lhs =y(45);
rhs =params(40)*y(9)+x(it_, 2);
residual(16)= lhs-rhs;
lhs =y(44);
rhs =params(41)*y(8)+x(it_, 3);
residual(17)= lhs-rhs;
lhs =y(24);
rhs =params(43)*y(2)+x(it_, 5);
residual(18)= lhs-rhs;
lhs =y(47);
rhs =y(52)+y(40)*(params(33)*params(35)+params(34)*(1-params(33)))-y(46)*params(34);
residual(19)= lhs-rhs;
lhs =y(48);
rhs =y(39)+y(40)*params(35);
residual(20)= lhs-rhs;
lhs =y(25);
rhs =y(52)+params(34)*(y(38)-y(36));
residual(21)= lhs-rhs;
lhs =y(49);
rhs =y(39)+(1-params(31))*(params(34)-T11)*(y(36)-y(35))-y(40)*(params(33)*((1-params(31))*params(34)+T11*params(31))+params(35)*(1-params(33))-T11);
residual(22)= lhs-rhs;
lhs =y(25);
rhs =y(57);
residual(23)= lhs-rhs;
lhs =y(51);
rhs =y(47)*(1-params(33))+params(33)*y(48);
residual(24)= lhs-rhs;
residual(25) = y(22)-params(11)*y(1)+params(11)*params(12)/(1-params(36)*params(11))*y(14);
lhs =y(15);
rhs =params(5)*(1+params(39))*(params(31)*y(45)+(1-params(31))*y(44))+y(39)*params(5)*(1-params(9))/params(9)-params(5)*(params(4)-(1-params(31))*params(9))/params(9)*y(18);
residual(26)= lhs-rhs;
lhs =y(17);
rhs =T215*(y(15)-y(39)+params(4)*y(18));
residual(27)= lhs-rhs;
lhs =y(18);
rhs =y(45)-y(44);
residual(28)= lhs-rhs;
lhs =y(19);
rhs =y(26)-y(18);
residual(29)= lhs-rhs;
lhs =y(20);
rhs =y(40)-y(17);
residual(30)= lhs-rhs;
lhs =y(21);
rhs =y(20)-(1-params(31))*y(19);
residual(31)= lhs-rhs;
lhs =y(13);
rhs =y(50)-y(15);
residual(32)= lhs-rhs;
lhs =y(14);
rhs =y(13)-y(21);
residual(33)= lhs-rhs;
lhs =y(50);
rhs =y(47)*params(31)*(1-params(33))+params(31)*params(33)*y(48)+(1-params(31))*y(25);
residual(34)= lhs-rhs;
lhs =y(52);
rhs =(1-params(31))*y(25)+y(47)*params(31)*(1-params(33))+params(31)*params(33)*y(49);
residual(35)= lhs-rhs;
lhs =y(23);
rhs =y(31)*params(31)+y(32)*(1-params(31));
residual(36)= lhs-rhs;
lhs =y(23);
rhs =y(22)-y(1);
residual(37)= lhs-rhs;
lhs =y(51);
rhs =y(45)+(1-params(46))*y(53)+params(46)*y(74);
residual(38)= lhs-rhs;
lhs =y(57);
rhs =y(44)+y(54);
residual(39)= lhs-rhs;
lhs =y(56)-y(38);
rhs =y(58);
residual(40)= lhs-rhs;
lhs =y(26);
rhs =y(36)-y(35);
residual(41)= lhs-rhs;
lhs =y(27);
rhs =y(40)*params(17)-y(26)*params(18);
residual(42)= lhs-rhs;
lhs =y(28);
rhs =y(52)+y(27);
residual(43)= lhs-rhs;
lhs =y(55);
rhs =y(53)*params(27)+y(54)*params(28)+params(29)*y(62)+params(30)*y(65);
residual(44)= lhs-rhs;
lhs =y(69);
rhs =y(74)+params(15)*y(68)*(params(6)-params(16))+y(59)-y(61);
residual(45)= lhs-rhs;
lhs =y(70);
rhs =y(39)+y(68)*params(6);
residual(46)= lhs-rhs;
lhs =y(29);
rhs =y(74)+params(16)*(y(59)-y(64));
residual(47)= lhs-rhs;
lhs =y(71);
rhs =y(74)+y(68)*(params(16)*(1-params(15))*(1-params(32))-params(16)*(1-params(32))-params(6)*(1-params(15)))-params(16)*(1-params(32))*(y(64)-y(61));
residual(48)= lhs-rhs;
lhs =y(66);
rhs =y(69)*(1-params(15))+params(15)*y(70);
residual(49)= lhs-rhs;
lhs =y(72);
rhs =T34*(1-params(45))*(1-params(45)*params(36))*y(60)+params(36)*y(79);
residual(50)= lhs-rhs;
lhs =y(73);
rhs =T34*(1-params(45))*(1-params(45)*params(36))*y(63)+params(36)*y(80);
residual(51)= lhs-rhs;
lhs =y(72);
rhs =y(61)-y(10);
residual(52)= lhs-rhs;
lhs =y(73);
rhs =y(64)-y(11);
residual(53)= lhs-rhs;
lhs =y(60);
rhs =y(56)-y(61)-y(45);
residual(54)= lhs-rhs;
lhs =y(63);
rhs =y(56)-y(64)-y(44);
residual(55)= lhs-rhs;
lhs =y(68);
rhs =y(41)+y(24)-y(61);
residual(56)= lhs-rhs;
lhs =y(66);
rhs =y(45)+y(62);
residual(57)= lhs-rhs;
lhs =y(67);
rhs =y(44)+y(65);
residual(58)= lhs-rhs;
lhs =y(74);
rhs =y(56)+y(53)-y(59);
residual(59)= lhs-rhs;
lhs =y(29);
rhs =y(67);
residual(60)= lhs-rhs;
lhs =y(75);
rhs =y(69)*(1-params(15))*params(32)+y(70)*params(15)*params(32)+y(29)*(1-params(32));
residual(61)= lhs-rhs;
lhs =y(30);
rhs =params(32)*y(72)+(1-params(32))*y(73)+params(15)*params(32)*(y(68)-y(12));
residual(62)= lhs-rhs;
lhs =y(74);
rhs =y(29)*(1-params(32))+y(69)*(1-params(15))*params(32)+y(71)*params(15)*params(32);
residual(63)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(63, 85);

  %
  % Jacobian matrix
  %

  g1(1,39)=T3;
  g1(1,46)=(-T11);
  g1(1,52)=1;
  g1(2,38)=T3;
  g1(2,52)=(-params(38));
  g1(2,55)=(-params(39));
  g1(2,56)=1;
  g1(3,31)=1;
  g1(3,76)=(-params(36));
  g1(3,33)=(-((1-params(45))*(1-params(45)*params(36))*T34));
  g1(4,32)=1;
  g1(4,77)=(-params(36));
  g1(4,34)=(-((1-params(45))*(1-params(45)*params(36))*T34));
  g1(5,31)=(-params(31));
  g1(5,32)=(-(1-params(31)));
  g1(5,37)=1;
  g1(5,6)=params(31)*params(33);
  g1(5,40)=(-(params(31)*params(33)));
  g1(6,31)=1;
  g1(6,3)=1;
  g1(6,35)=T3;
  g1(7,32)=1;
  g1(7,4)=1;
  g1(7,36)=T3;
  g1(8,33)=1;
  g1(8,35)=1;
  g1(8,45)=1;
  g1(8,56)=(-(1-params(46)));
  g1(8,59)=(-params(46));
  g1(9,34)=1;
  g1(9,36)=1;
  g1(9,44)=1;
  g1(9,56)=T3;
  g1(10,24)=T3;
  g1(10,35)=1;
  g1(10,40)=1;
  g1(10,41)=T3;
  g1(11,41)=1;
  g1(11,78)=T3;
  g1(11,42)=1;
  g1(11,43)=T3;
  g1(12,24)=T3;
  g1(12,38)=1;
  g1(12,41)=T3;
  g1(12,46)=1;
  g1(13,16)=1;
  g1(13,19)=1-params(31);
  g1(13,20)=T3;
  g1(14,5)=(-params(42));
  g1(14,39)=1;
  g1(14,81)=T3;
  g1(15,7)=(-params(44));
  g1(15,43)=1;
  g1(15,84)=T3;
  g1(16,9)=(-params(40));
  g1(16,45)=1;
  g1(16,82)=T3;
  g1(17,8)=(-params(41));
  g1(17,44)=1;
  g1(17,83)=T3;
  g1(18,2)=(-params(43));
  g1(18,24)=1;
  g1(18,85)=T3;
  g1(19,40)=(-(params(33)*params(35)+params(34)*(1-params(33))));
  g1(19,46)=params(34);
  g1(19,47)=1;
  g1(19,52)=T3;
  g1(20,39)=T3;
  g1(20,40)=(-params(35));
  g1(20,48)=1;
  g1(21,25)=1;
  g1(21,36)=params(34);
  g1(21,38)=(-params(34));
  g1(21,52)=T3;
  g1(22,35)=(1-params(31))*(params(34)-T11);
  g1(22,36)=(-((1-params(31))*(params(34)-T11)));
  g1(22,39)=T3;
  g1(22,40)=params(33)*((1-params(31))*params(34)+T11*params(31))+params(35)*(1-params(33))-T11;
  g1(22,49)=1;
  g1(23,25)=1;
  g1(23,57)=T3;
  g1(24,47)=(-(1-params(33)));
  g1(24,48)=(-params(33));
  g1(24,51)=1;
  g1(25,14)=params(11)*params(12)/(1-params(36)*params(11));
  g1(25,1)=(-params(11));
  g1(25,22)=1;
  g1(26,15)=1;
  g1(26,18)=params(5)*(params(4)-(1-params(31))*params(9))/params(9);
  g1(26,39)=(-(params(5)*(1-params(9))/params(9)));
  g1(26,44)=(-((1-params(31))*params(5)*(1+params(39))));
  g1(26,45)=(-(params(31)*params(5)*(1+params(39))));
  g1(27,15)=(-T215);
  g1(27,17)=1;
  g1(27,18)=(-(params(4)*T215));
  g1(27,39)=T215;
  g1(28,18)=1;
  g1(28,44)=1;
  g1(28,45)=T3;
  g1(29,18)=1;
  g1(29,19)=1;
  g1(29,26)=T3;
  g1(30,17)=1;
  g1(30,20)=1;
  g1(30,40)=T3;
  g1(31,19)=1-params(31);
  g1(31,20)=T3;
  g1(31,21)=1;
  g1(32,13)=1;
  g1(32,15)=1;
  g1(32,50)=T3;
  g1(33,13)=T3;
  g1(33,14)=1;
  g1(33,21)=1;
  g1(34,25)=(-(1-params(31)));
  g1(34,47)=(-(params(31)*(1-params(33))));
  g1(34,48)=(-(params(31)*params(33)));
  g1(34,50)=1;
  g1(35,25)=(-(1-params(31)));
  g1(35,47)=(-(params(31)*(1-params(33))));
  g1(35,49)=(-(params(31)*params(33)));
  g1(35,52)=1;
  g1(36,23)=1;
  g1(36,31)=(-params(31));
  g1(36,32)=(-(1-params(31)));
  g1(37,1)=1;
  g1(37,22)=T3;
  g1(37,23)=1;
  g1(38,45)=T3;
  g1(38,51)=1;
  g1(38,53)=(-(1-params(46)));
  g1(38,74)=(-params(46));
  g1(39,44)=T3;
  g1(39,54)=T3;
  g1(39,57)=1;
  g1(40,38)=T3;
  g1(40,56)=1;
  g1(40,58)=T3;
  g1(41,26)=1;
  g1(41,35)=1;
  g1(41,36)=T3;
  g1(42,26)=params(18);
  g1(42,27)=1;
  g1(42,40)=(-params(17));
  g1(43,27)=T3;
  g1(43,28)=1;
  g1(43,52)=T3;
  g1(44,53)=(-params(27));
  g1(44,54)=(-params(28));
  g1(44,55)=1;
  g1(44,62)=(-params(29));
  g1(44,65)=(-params(30));
  g1(45,59)=T3;
  g1(45,61)=1;
  g1(45,68)=(-(params(15)*(params(6)-params(16))));
  g1(45,69)=1;
  g1(45,74)=T3;
  g1(46,39)=T3;
  g1(46,68)=(-params(6));
  g1(46,70)=1;
  g1(47,29)=1;
  g1(47,59)=(-params(16));
  g1(47,64)=params(16);
  g1(47,74)=T3;
  g1(48,61)=(-(params(16)*(1-params(32))));
  g1(48,64)=params(16)*(1-params(32));
  g1(48,68)=(-(params(16)*(1-params(15))*(1-params(32))-params(16)*(1-params(32))-params(6)*(1-params(15))));
  g1(48,71)=1;
  g1(48,74)=T3;
  g1(49,66)=1;
  g1(49,69)=(-(1-params(15)));
  g1(49,70)=(-params(15));
  g1(50,60)=(-((1-params(45))*(1-params(45)*params(36))*T34));
  g1(50,72)=1;
  g1(50,79)=(-params(36));
  g1(51,63)=(-((1-params(45))*(1-params(45)*params(36))*T34));
  g1(51,73)=1;
  g1(51,80)=(-params(36));
  g1(52,10)=1;
  g1(52,61)=T3;
  g1(52,72)=1;
  g1(53,11)=1;
  g1(53,64)=T3;
  g1(53,73)=1;
  g1(54,45)=1;
  g1(54,56)=T3;
  g1(54,60)=1;
  g1(54,61)=1;
  g1(55,44)=1;
  g1(55,56)=T3;
  g1(55,63)=1;
  g1(55,64)=1;
  g1(56,24)=T3;
  g1(56,41)=T3;
  g1(56,61)=1;
  g1(56,68)=1;
  g1(57,45)=T3;
  g1(57,62)=T3;
  g1(57,66)=1;
  g1(58,44)=T3;
  g1(58,65)=T3;
  g1(58,67)=1;
  g1(59,53)=T3;
  g1(59,56)=T3;
  g1(59,59)=1;
  g1(59,74)=1;
  g1(60,29)=1;
  g1(60,67)=T3;
  g1(61,29)=(-(1-params(32)));
  g1(61,69)=(-((1-params(15))*params(32)));
  g1(61,70)=(-(params(15)*params(32)));
  g1(61,75)=1;
  g1(62,30)=1;
  g1(62,12)=params(15)*params(32);
  g1(62,68)=(-(params(15)*params(32)));
  g1(62,72)=(-params(32));
  g1(62,73)=(-(1-params(32)));
  g1(63,29)=(-(1-params(32)));
  g1(63,69)=(-((1-params(15))*params(32)));
  g1(63,71)=(-(params(15)*params(32)));
  g1(63,74)=1;

if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],63,7225);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],63,614125);
end
end
end
end
