function [residual, g1, g2, g3] = tn7_static(y, x, params)
%
% Status : Computes static model for Dynare
%
% Inputs : 
%   y         [M_.endo_nbr by 1] double    vector of endogenous variables in declaration order
%   x         [M_.exo_nbr by 1] double     vector of exogenous variables in declaration order
%   params    [M_.param_nbr by 1] double   vector of parameter values in declaration order
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the static model equations 
%                                          in order of declaration of the equations.
%                                          Dynare may prepend or append auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by M_.endo_nbr] double    Jacobian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g2        [M_.endo_nbr by (M_.endo_nbr)^2] double   Hessian matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%   g3        [M_.endo_nbr by (M_.endo_nbr)^3] double   Third derivatives matrix of the static model equations;
%                                                       columns: variables in declaration order
%                                                       rows: equations in order of declaration
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

residual = zeros( 63, 1);

%
% Model equations
%

T11 = 1/params(38);
T34 = params(45)^(-1);
T198 = 1/params(9);
lhs =y(40);
rhs =y(27)+T11*y(34);
residual(1)= lhs-rhs;
lhs =y(44)-y(26);
rhs =y(40)*params(38)+params(39)*y(43);
residual(2)= lhs-rhs;
lhs =y(19);
rhs =(1-params(45))*(1-params(45)*params(36))*y(21)*T34+y(19)*params(36);
residual(3)= lhs-rhs;
lhs =y(20);
rhs =T34*(1-params(45))*(1-params(45)*params(36))*y(22)+params(36)*y(20);
residual(4)= lhs-rhs;
lhs =y(25);
rhs =y(19)*params(31)+y(20)*(1-params(31));
residual(5)= lhs-rhs;
residual(6) = y(19);
residual(7) = y(20);
lhs =y(21);
rhs =y(44)*(1-params(46))-y(23)-y(33)+params(46)*y(47);
residual(8)= lhs-rhs;
lhs =y(22);
rhs =y(44)-y(24)-y(32);
residual(9)= lhs-rhs;
lhs =y(28);
rhs =y(29)+y(12)-y(23);
residual(10)= lhs-rhs;
lhs =y(30);
rhs =y(29)+y(31)-y(29);
residual(11)= lhs-rhs;
lhs =y(34);
rhs =y(29)+y(12)-y(26);
residual(12)= lhs-rhs;
lhs =y(4);
rhs =y(8)-(1-params(31))*y(7);
residual(13)= lhs-rhs;
lhs =y(27);
rhs =y(27)*params(42)+x(1);
residual(14)= lhs-rhs;
lhs =y(31);
rhs =y(31)*params(44)+x(4);
residual(15)= lhs-rhs;
lhs =y(33);
rhs =y(33)*params(40)+x(2);
residual(16)= lhs-rhs;
lhs =y(32);
rhs =y(32)*params(41)+x(3);
residual(17)= lhs-rhs;
lhs =y(12);
rhs =y(12)*params(43)+x(5);
residual(18)= lhs-rhs;
lhs =y(35);
rhs =y(40)+y(28)*(params(33)*params(35)+params(34)*(1-params(33)))-y(34)*params(34);
residual(19)= lhs-rhs;
lhs =y(36);
rhs =y(27)+y(28)*params(35);
residual(20)= lhs-rhs;
lhs =y(13);
rhs =y(40)+params(34)*(y(26)-y(24));
residual(21)= lhs-rhs;
lhs =y(37);
rhs =y(27)+(1-params(31))*(params(34)-T11)*(y(24)-y(23))-y(28)*(params(33)*((1-params(31))*params(34)+T11*params(31))+params(35)*(1-params(33))-T11);
residual(22)= lhs-rhs;
lhs =y(13);
rhs =y(45);
residual(23)= lhs-rhs;
lhs =y(39);
rhs =y(35)*(1-params(33))+params(33)*y(36);
residual(24)= lhs-rhs;
residual(25) = y(10)-y(10)*params(11)+params(11)*params(12)/(1-params(36)*params(11))*y(2);
lhs =y(3);
rhs =params(5)*(1+params(39))*(params(31)*y(33)+(1-params(31))*y(32))+y(27)*params(5)*(1-params(9))/params(9)-params(5)*(params(4)-(1-params(31))*params(9))/params(9)*y(6);
residual(26)= lhs-rhs;
lhs =y(5);
rhs =T198*(y(3)-y(27)+params(4)*y(6));
residual(27)= lhs-rhs;
lhs =y(6);
rhs =y(33)-y(32);
residual(28)= lhs-rhs;
lhs =y(7);
rhs =y(14)-y(6);
residual(29)= lhs-rhs;
lhs =y(8);
rhs =y(28)-y(5);
residual(30)= lhs-rhs;
lhs =y(9);
rhs =y(8)-(1-params(31))*y(7);
residual(31)= lhs-rhs;
lhs =y(1);
rhs =y(38)-y(3);
residual(32)= lhs-rhs;
lhs =y(2);
rhs =y(1)-y(9);
residual(33)= lhs-rhs;
lhs =y(38);
rhs =y(35)*params(31)*(1-params(33))+params(31)*params(33)*y(36)+(1-params(31))*y(13);
residual(34)= lhs-rhs;
lhs =y(40);
rhs =(1-params(31))*y(13)+y(35)*params(31)*(1-params(33))+params(31)*params(33)*y(37);
residual(35)= lhs-rhs;
lhs =y(11);
rhs =y(19)*params(31)+y(20)*(1-params(31));
residual(36)= lhs-rhs;
residual(37) = y(11);
lhs =y(39);
rhs =y(33)+(1-params(46))*y(41)+params(46)*y(62);
residual(38)= lhs-rhs;
lhs =y(45);
rhs =y(32)+y(42);
residual(39)= lhs-rhs;
lhs =y(44)-y(26);
rhs =y(46);
residual(40)= lhs-rhs;
lhs =y(14);
rhs =y(24)-y(23);
residual(41)= lhs-rhs;
lhs =y(15);
rhs =y(28)*params(17)-y(14)*params(18);
residual(42)= lhs-rhs;
lhs =y(16);
rhs =y(40)+y(15);
residual(43)= lhs-rhs;
lhs =y(43);
rhs =y(41)*params(27)+y(42)*params(28)+params(29)*y(50)+params(30)*y(53);
residual(44)= lhs-rhs;
lhs =y(57);
rhs =y(62)+params(15)*y(56)*(params(6)-params(16))+y(47)-y(49);
residual(45)= lhs-rhs;
lhs =y(58);
rhs =y(27)+y(56)*params(6);
residual(46)= lhs-rhs;
lhs =y(17);
rhs =y(62)+params(16)*(y(47)-y(52));
residual(47)= lhs-rhs;
lhs =y(59);
rhs =y(62)+y(56)*(params(16)*(1-params(15))*(1-params(32))-params(16)*(1-params(32))-params(6)*(1-params(15)))-params(16)*(1-params(32))*(y(52)-y(49));
residual(48)= lhs-rhs;
lhs =y(54);
rhs =y(57)*(1-params(15))+params(15)*y(58);
residual(49)= lhs-rhs;
lhs =y(60);
rhs =T34*(1-params(45))*(1-params(45)*params(36))*y(48)+params(36)*y(60);
residual(50)= lhs-rhs;
lhs =y(61);
rhs =T34*(1-params(45))*(1-params(45)*params(36))*y(51)+params(36)*y(61);
residual(51)= lhs-rhs;
residual(52) = y(60);
residual(53) = y(61);
lhs =y(48);
rhs =y(44)-y(49)-y(33);
residual(54)= lhs-rhs;
lhs =y(51);
rhs =y(44)-y(52)-y(32);
residual(55)= lhs-rhs;
lhs =y(56);
rhs =y(29)+y(12)-y(49);
residual(56)= lhs-rhs;
lhs =y(54);
rhs =y(33)+y(50);
residual(57)= lhs-rhs;
lhs =y(55);
rhs =y(32)+y(53);
residual(58)= lhs-rhs;
lhs =y(62);
rhs =y(44)+y(41)-y(47);
residual(59)= lhs-rhs;
lhs =y(17);
rhs =y(55);
residual(60)= lhs-rhs;
lhs =y(63);
rhs =y(57)*(1-params(15))*params(32)+y(58)*params(15)*params(32)+y(17)*(1-params(32));
residual(61)= lhs-rhs;
lhs =y(18);
rhs =params(32)*y(60)+(1-params(32))*y(61);
residual(62)= lhs-rhs;
lhs =y(62);
rhs =y(17)*(1-params(32))+y(57)*(1-params(15))*params(32)+y(59)*params(15)*params(32);
residual(63)= lhs-rhs;
if ~isreal(residual)
  residual = real(residual)+imag(residual).^2;
end
if nargout >= 2,
  g1 = zeros(63, 63);

  %
  % Jacobian matrix
  %

  g1(1,27)=(-1);
  g1(1,34)=(-T11);
  g1(1,40)=1;
  g1(2,26)=(-1);
  g1(2,40)=(-params(38));
  g1(2,43)=(-params(39));
  g1(2,44)=1;
  g1(3,19)=1-params(36);
  g1(3,21)=(-((1-params(45))*(1-params(45)*params(36))*T34));
  g1(4,20)=1-params(36);
  g1(4,22)=(-((1-params(45))*(1-params(45)*params(36))*T34));
  g1(5,19)=(-params(31));
  g1(5,20)=(-(1-params(31)));
  g1(5,25)=1;
  g1(6,19)=1;
  g1(7,20)=1;
  g1(8,21)=1;
  g1(8,23)=1;
  g1(8,33)=1;
  g1(8,44)=(-(1-params(46)));
  g1(8,47)=(-params(46));
  g1(9,22)=1;
  g1(9,24)=1;
  g1(9,32)=1;
  g1(9,44)=(-1);
  g1(10,12)=(-1);
  g1(10,23)=1;
  g1(10,28)=1;
  g1(10,29)=(-1);
  g1(11,30)=1;
  g1(11,31)=(-1);
  g1(12,12)=(-1);
  g1(12,26)=1;
  g1(12,29)=(-1);
  g1(12,34)=1;
  g1(13,4)=1;
  g1(13,7)=1-params(31);
  g1(13,8)=(-1);
  g1(14,27)=1-params(42);
  g1(15,31)=1-params(44);
  g1(16,33)=1-params(40);
  g1(17,32)=1-params(41);
  g1(18,12)=1-params(43);
  g1(19,28)=(-(params(33)*params(35)+params(34)*(1-params(33))));
  g1(19,34)=params(34);
  g1(19,35)=1;
  g1(19,40)=(-1);
  g1(20,27)=(-1);
  g1(20,28)=(-params(35));
  g1(20,36)=1;
  g1(21,13)=1;
  g1(21,24)=params(34);
  g1(21,26)=(-params(34));
  g1(21,40)=(-1);
  g1(22,23)=(1-params(31))*(params(34)-T11);
  g1(22,24)=(-((1-params(31))*(params(34)-T11)));
  g1(22,27)=(-1);
  g1(22,28)=params(33)*((1-params(31))*params(34)+T11*params(31))+params(35)*(1-params(33))-T11;
  g1(22,37)=1;
  g1(23,13)=1;
  g1(23,45)=(-1);
  g1(24,35)=(-(1-params(33)));
  g1(24,36)=(-params(33));
  g1(24,39)=1;
  g1(25,2)=params(11)*params(12)/(1-params(36)*params(11));
  g1(25,10)=1-params(11);
  g1(26,3)=1;
  g1(26,6)=params(5)*(params(4)-(1-params(31))*params(9))/params(9);
  g1(26,27)=(-(params(5)*(1-params(9))/params(9)));
  g1(26,32)=(-((1-params(31))*params(5)*(1+params(39))));
  g1(26,33)=(-(params(31)*params(5)*(1+params(39))));
  g1(27,3)=(-T198);
  g1(27,5)=1;
  g1(27,6)=(-(params(4)*T198));
  g1(27,27)=T198;
  g1(28,6)=1;
  g1(28,32)=1;
  g1(28,33)=(-1);
  g1(29,6)=1;
  g1(29,7)=1;
  g1(29,14)=(-1);
  g1(30,5)=1;
  g1(30,8)=1;
  g1(30,28)=(-1);
  g1(31,7)=1-params(31);
  g1(31,8)=(-1);
  g1(31,9)=1;
  g1(32,1)=1;
  g1(32,3)=1;
  g1(32,38)=(-1);
  g1(33,1)=(-1);
  g1(33,2)=1;
  g1(33,9)=1;
  g1(34,13)=(-(1-params(31)));
  g1(34,35)=(-(params(31)*(1-params(33))));
  g1(34,36)=(-(params(31)*params(33)));
  g1(34,38)=1;
  g1(35,13)=(-(1-params(31)));
  g1(35,35)=(-(params(31)*(1-params(33))));
  g1(35,37)=(-(params(31)*params(33)));
  g1(35,40)=1;
  g1(36,11)=1;
  g1(36,19)=(-params(31));
  g1(36,20)=(-(1-params(31)));
  g1(37,11)=1;
  g1(38,33)=(-1);
  g1(38,39)=1;
  g1(38,41)=(-(1-params(46)));
  g1(38,62)=(-params(46));
  g1(39,32)=(-1);
  g1(39,42)=(-1);
  g1(39,45)=1;
  g1(40,26)=(-1);
  g1(40,44)=1;
  g1(40,46)=(-1);
  g1(41,14)=1;
  g1(41,23)=1;
  g1(41,24)=(-1);
  g1(42,14)=params(18);
  g1(42,15)=1;
  g1(42,28)=(-params(17));
  g1(43,15)=(-1);
  g1(43,16)=1;
  g1(43,40)=(-1);
  g1(44,41)=(-params(27));
  g1(44,42)=(-params(28));
  g1(44,43)=1;
  g1(44,50)=(-params(29));
  g1(44,53)=(-params(30));
  g1(45,47)=(-1);
  g1(45,49)=1;
  g1(45,56)=(-(params(15)*(params(6)-params(16))));
  g1(45,57)=1;
  g1(45,62)=(-1);
  g1(46,27)=(-1);
  g1(46,56)=(-params(6));
  g1(46,58)=1;
  g1(47,17)=1;
  g1(47,47)=(-params(16));
  g1(47,52)=params(16);
  g1(47,62)=(-1);
  g1(48,49)=(-(params(16)*(1-params(32))));
  g1(48,52)=params(16)*(1-params(32));
  g1(48,56)=(-(params(16)*(1-params(15))*(1-params(32))-params(16)*(1-params(32))-params(6)*(1-params(15))));
  g1(48,59)=1;
  g1(48,62)=(-1);
  g1(49,54)=1;
  g1(49,57)=(-(1-params(15)));
  g1(49,58)=(-params(15));
  g1(50,48)=(-((1-params(45))*(1-params(45)*params(36))*T34));
  g1(50,60)=1-params(36);
  g1(51,51)=(-((1-params(45))*(1-params(45)*params(36))*T34));
  g1(51,61)=1-params(36);
  g1(52,60)=1;
  g1(53,61)=1;
  g1(54,33)=1;
  g1(54,44)=(-1);
  g1(54,48)=1;
  g1(54,49)=1;
  g1(55,32)=1;
  g1(55,44)=(-1);
  g1(55,51)=1;
  g1(55,52)=1;
  g1(56,12)=(-1);
  g1(56,29)=(-1);
  g1(56,49)=1;
  g1(56,56)=1;
  g1(57,33)=(-1);
  g1(57,50)=(-1);
  g1(57,54)=1;
  g1(58,32)=(-1);
  g1(58,53)=(-1);
  g1(58,55)=1;
  g1(59,41)=(-1);
  g1(59,44)=(-1);
  g1(59,47)=1;
  g1(59,62)=1;
  g1(60,17)=1;
  g1(60,55)=(-1);
  g1(61,17)=(-(1-params(32)));
  g1(61,57)=(-((1-params(15))*params(32)));
  g1(61,58)=(-(params(15)*params(32)));
  g1(61,63)=1;
  g1(62,18)=1;
  g1(62,60)=(-params(32));
  g1(62,61)=(-(1-params(32)));
  g1(63,17)=(-(1-params(32)));
  g1(63,57)=(-((1-params(15))*params(32)));
  g1(63,59)=(-(params(15)*params(32)));
  g1(63,62)=1;
  if ~isreal(g1)
    g1 = real(g1)+2*imag(g1);
  end
if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],63,3969);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],63,250047);
end
end
end
end
