// Monetary Policy and Net Exports Externalities in the Small Open Economy (Jae Hun Shim)

@#define OPTIMAL =1
@#define DTR =0 
@#define CTR =0
@#define PEG =0
@#define ACT =0
@#define ADT =0
@#define ANT =0


 
@#if DTR == 1 
case_title='domestic inflation-based Taylor rule (DTR)'; 
@#else 
@#if ANT == 1 
case_title='Augmentated net exports-based Taylor rule (ANT)'; 
@#else 
@#if CTR ==1 
case_title='CPI inflation-based Taylor rule (CTR)'; 
@#else
@#if ACT ==1 
case_title='Augmentated CPI inflation-based Taylor rule (PT)'; 
@#else
@#if ADT ==1 
case_title='Augmentated Domestic inflation-based Taylor rule (PT)'; 
@#else
@#if PEG ==1 
case_title='exchange rate peg (PEG)'; 
@#else 
@#if OPTIMAL ==1 
case_title='Optimal Policy'; 
@#else 
error('One case must be set to 1') 
@#endif 
@#endif 
@#endif 
@#endif 
@#endif 
@#endif 
@#endif



var pht phn pdt nx sna ena sg eg og nxg pd yg yna rna at aht ahn e pt pn pi yf s x i pf y;


varexo yf_ pf_ aht_ ahn_ ;        
                                      // aht_ = shocks in tradable production productivity in SOE
								      // ahn_ = shocks in non-tradable production productivity in SOE									  
                                      // yf_ = shocks in foreign output
									  // pf_ = shocks in foreign inflation
									 

parameters taynx sigaht sigahn zv del zi wai phii vi kappa mu tao lamda nu rhoaht rhoahn tayp tayy sigma alpha omega eta beta epsilon rho phi rhoyf rhopf theta;

taynx = 0.125;
sigaht = 0.0242;
sigahn = 0.0169;
nu = 0.8;
beta = 0.99;
sigma = 0.58;
alpha = 0.3/0.58;
lamda = 1 - alpha;
omega = 0.74;
eta = 1.5;
rho = 1;
epsilon = 6;
theta = 0.75;
phi = 3;

rhoaht = 0.61;
rhoahn = 0.52;
rhoyf = 0.89;
rhopf = 0.86;

tayp = 1.5;
tayy=0.125;
wai = sigma*alpha*(omega-1);
phii = sigma*alpha*(eta+lamda*(eta-omega));
mu = (wai+1)*(1-sigma*alpha) + phii;
tao = (wai+1)*(1-sigma);
vi = ((1-beta*theta)*(1-theta)/theta);
zi = ((1-sigma*alpha)/((1+wai)*(1-sigma*alpha)+phii));
kappa = mu*(1+phi)/(mu*(1+phi) + beta*mu*(1+phi) + epsilon*vi*phi*(phi*mu + 1));
del = (1-sqrt(1-4*beta*(kappa^(2))))/(2*kappa*beta);
zv = mu/(1+phi*mu);


model(linear);

// net exports
nx = sigma*alpha*(eta - 1 + alpha*(omega*(1 - sigma) + sigma) + lamda*eta - 1)*s - sigma*alpha*(1-sigma)*(omega-1)*e;

// IS equation
yg = yg(+1) - (nx(+1) - nx) - (i - sigma*pt(+1) - (1-sigma)*pn(+1) - rna);

// Natural Level of Output
yna = zv*(1+phi)*at + zv*((1-mu)/mu)*yf - zv*((tao-mu*(1-sigma))/mu)*ena;

// Natural Level of Terms of Trade
sna = (1/mu)*(yna - yf + tao*ena);

// Natural Level of Relative Price
ena = aht - ahn;

// Definition of outout gap
yg = y - yna;

// Definition of relative price gap
eg = e - ena;

// Definition of terms of trade gap
sg = s - sna;

// Definition of open economy gap
og = sg - (1-sigma)*eg;

// Definition of net exports gap
nxg = yg - og;

// Nature Rate of Interest Rate 
rna = zv*((tao - mu*(1+(phi*sigma)))/mu)*aht*(1 - rhoaht) - zv*((tao+mu*phi*(1-sigma))/mu)*ahn*(1-rhoahn) + zv*((1-mu)/mu)*(yf(+1)-yf);

// Domestic Tradable New Keynesian Philips Curve
pt   = vi*(phi*yg + sg) + beta*pt(+1); 

// Definition of Tradable Inflation
pt = pht - pht(-1);

// Domestic Non-Tradable New Keynesian Philips Curve              
pn   = vi*(phi*yg + sg - eg) + beta*pn(+1);

// Definition of Non-Tradable Inflation
pn = phn - phn(-1);                 

// CPI inflation
pi   = beta*pi(+1) + vi*((1+phi)*yg - nxg) - sigma*alpha*(beta*(s(+1) - s) - (s-s(-1)));                      

// Definition of Terms of Trade
s = s(-1) + x - x(-1) + pf - pt;                                             

// Exogenous Process of Foreign Output
yf   = rhoyf*yf(-1) + yf_; 

// Exogenous Process of Foreign Inflation  
pf   = rhopf*pf(-1) + pf_;   

// Exogenous Process of Tradable Productivity                                                    
aht = rhoaht*aht(-1) + aht_;    

// Exogenous Process of Non-Tradable Productivity                                                       
ahn = rhoahn*ahn(-1) + ahn_;                                                          
 

@#if DTR == 1 
i= tayp*(sigma*pt + (1-sigma)*pn); // domestic inflation-based Taylor rule (DTR) 
@#else 
@#if CTR ==1 
i =tayp*pi; // CPI inflation-based Taylor rule (CTR) 
@#else 
@#if PEG ==1 
x=0; //exchange rate peg (PEG) 
@#else 
@#if OPTIMAL ==1 
pdt - ((1-sqrt(1-4*beta*(((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))/((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))*(1+phi) + epsilon*(((1-beta*theta)*(1-theta)/theta))*(phi*(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega)))) + 1)))^(2))))/(2*((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))/((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))*(1+phi) + epsilon*(((1-beta*theta)*(1-theta)/theta))*(phi*(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega)))) + 1)))*beta))*pdt(-1) + (((1-sqrt(1-4*beta*(((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))/((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))*(1+phi) + epsilon*(((1-beta*theta)*(1-theta)/theta))*(phi*(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega)))) + 1)))^(2))))/(2*((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))/((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))*(1+phi) + epsilon*(((1-beta*theta)*(1-theta)/theta))*(phi*(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega)))) + 1)))*beta))*(((1-beta*theta)*(1-theta)/theta))/(1-((1-sqrt(1-4*beta*(((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))/((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))*(1+phi) + epsilon*(((1-beta*theta)*(1-theta)/theta))*(phi*(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega)))) + 1)))^(2))))/(2*((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))/((((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega))))*(1+phi) + epsilon*(((1-beta*theta)*(1-theta)/theta))*(phi*(((sigma*alpha*(omega-1))+1)*(1-sigma*alpha) + (sigma*alpha*(eta+lamda*(eta-omega)))) + 1)))*beta))*beta))*nxg = 0;
@#else
@#if ACT ==1 
i = nu*i(-1) + (1-nu)*tayp*pi;  
@#else
@#if ADT ==1 
i = nu*i(-1) + (1-nu)*tayp*(sigma*pt + (1-sigma)*pn);  
@#else
@#if ANT ==1 
i = nu*i(-1) + (1-nu)*(tayp*(sigma*pt + (1-sigma)*pn) - taynx*nx);  
@#else
@#endif 
@#endif 
@#endif 
@#endif
@#endif 
@#endif   
@#endif
                                                                     

// Market Clearing Condition
y = yf + mu*s - tao*e;                                                                          

// Definition of Relative Home Producer Price
e = e(-1) - pt + pn;                                                                                                 

// Definition of Composite Domestic Inflation                   
pd = sigma*pt + (1-sigma)*pn;

// Definition of Domestic Inflation
pd = pdt - pdt(-1);

// Aggregate Productivity 
at = sigma*aht + (1 - sigma)*ahn;                                                         
end;


steady;
check;

shocks;  
var yf_; stderr 0.0054; 
end;

stoch_simul(order=1, irf=30, irf_plot_threshold=0, noprint);
                                         
var_string={'pt', 'pn', 'pd', 'yg', 'og', 'nx', 'nxg'};

for var_iter=1:length(var_string) 
var_pos=strmatch(var_string{var_iter},M_.endo_names,'exact'); 
cyc_moments(var_iter,1)=sqrt(oo_.var(var_pos,var_pos))*100; 
 

pt_pos=strmatch('pt',M_.endo_names,'exact');
pn_pos=strmatch('pn',M_.endo_names,'exact');
yg_pos=strmatch('yg',M_.endo_names,'exact');


stoch_simul(order=1, irf=0, noprint);

V(1,1)= (((1-sigma*alpha)/((1+wai)*(1-sigma*alpha)+phii))/2)*((epsilon/((1-beta*theta)*(1-theta)/theta))*(sigma*oo_.var(pt_pos,pt_pos) + (1 - sigma)*oo_.var(pn_pos,pn_pos)) + (1 + phi)*oo_.var(yg_pos,yg_pos))*100;


end;

@#if DTR == 1
save('J_DTR','V','cyc_moments','M_','oo_','options_','case_title');
@#else
@#if CTR ==1
save('J_CTR','V','cyc_moments','M_','oo_','options_','case_title');
@#else
@#if PEG ==1
save('J_PEG','V','M_','cyc_moments','oo_','options_','case_title');
@#else
@#if OPTIMAL ==1
save('J_OPTIMAL','V','M_','cyc_moments','oo_','options_','case_title');
@#else
@#if ACT ==1
save('J_ACT','V','M_','cyc_moments','oo_','options_','case_title');
@#else
@#if ADT ==1
save('J_ADT','V','M_','cyc_moments','oo_','options_','case_title');
@#else
@#if ANT ==1
save('J_ANT','V','M_','cyc_moments','oo_','options_','case_title');
@#else
error('Undefined case')
@#endif
@#endif
@#endif
@#endif
@#endif
@#endif
@#endif



    DTR=load('J_DTR.mat'); 
    CTR=load('J_CTR.mat');
    PEG=load('J_PEG.mat');
    OPTIMAL=load('J_OPTIMAL.mat');
    ACT=load('J_ACT.mat'); 
    ADT=load('J_ADT.mat');
    ANT=load('J_ANT.mat');



var_string={'pt', 'pn', 'pd', 'yg', 'og', 'nx', 'nxg'};

    fprintf('\nTABLE 1: Cyclical properties of alternative policy regimes\n')
    fprintf('%20s \t %3s \t %3s \t %3s \t %3s \t %3s \t %3s \t %3s \n','','DTR','CTR','PEG','OPTIMAL','ACT','ADT','ANT')
    fprintf('%20s \t %3s \t %3s \t %3s \t %3s \t %3s \t %3s \t %3s \n','','sd%','sd%','sd%','sd%','sd%','sd%','sd%')
    for var_iter=1:length(var_string)
    fprintf('%20s \t %3.2f \t %3.2f \t %3.2f \t %3.2f \t %3.2f \t %3.2f \t %3.2f \n',M_.endo_names_long(strmatch(var_string{var_iter},M_.endo_names,'exact'),:),DTR.cyc_moments(var_iter),CTR.cyc_moments(var_iter),PEG.cyc_moments(var_iter),OPTIMAL.cyc_moments(var_iter),ACT.cyc_moments(var_iter),ADT.cyc_moments(var_iter),ANT.cyc_moments(var_iter))
end;


case_string={'standard'};
    fprintf('\nTABLE 2: welfare losses\n')
    fprintf('%20s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \t %6s \n','','DTR','CTR','PEG','OPTIMAL','ACT','ADT','ANT')
    for case_iter=1:1
        fprintf('%-s \n',case_string{case_iter});
        fprintf('%-20s \t %5.4f \t %5.4f \t %5.4f \t %5.4f \t %5.4f \t %5.4f  \t %5.4f \n\n','Total',DTR.V(1,case_iter),CTR.V(1,case_iter),PEG.V(1,case_iter),OPTIMAL.V(1,case_iter),ACT.V(1,case_iter),ADT.V(1,case_iter),ANT.V(1,case_iter))


end;



