function [residual, g1, g2, g3] = wel4_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(27, 1);
T60 = params(4)*(1-params(11))/params(11);
T74 = 1/params(11);
T219 = ((1+params(19)*params(20)*(params(21)-1))*(1-params(19)*params(20))+params(19)*params(20)*(params(22)+params(13)*(params(22)-params(21))))/((1+params(26))*((1+params(19)*params(20)*(params(21)-1))*(1-params(19)*params(20))+params(19)*params(20)*(params(22)+params(13)*(params(22)-params(21))))+params(24)*(1-params(23)*params(29))*(1-params(29))/params(29)*(1+params(26)*((1+params(19)*params(20)*(params(21)-1))*(1-params(19)*params(20))+params(19)*params(20)*(params(22)+params(13)*(params(22)-params(21))))));
T227 = (1-sqrt(1-params(23)*4*T219^2))/(params(23)*2*T219);
T234 = (1-params(23)*params(29))*(1-params(29))/params(29)*T227/(1-params(23)*T227);
lhs =y(14);
rhs =params(19)*params(20)*(params(22)-1+params(20)*(params(19)+params(21)*(1-params(19)))+params(22)*params(13)-1)*y(33)-params(19)*params(20)*(1-params(19))*(params(21)-1)*y(28);
residual(1)= lhs-rhs;
lhs =y(22);
rhs =y(39)-(y(38)-y(14))-(y(35)-params(19)*y(40)-(1-params(19))*y(41)-y(24));
residual(2)= lhs-rhs;
lhs =y(23);
rhs =params(4)*(1+params(26))*y(25)+T60*y(32)-params(4)*(params(12)-(1-params(19))*params(11))/params(11)*y(16);
residual(3)= lhs-rhs;
lhs =y(15);
rhs =T74*(y(23)-y(32)+params(12)*y(16));
residual(4)= lhs-rhs;
lhs =y(16);
rhs =y(26)-y(27);
residual(5)= lhs-rhs;
lhs =y(22);
rhs =y(37)-y(23);
residual(6)= lhs-rhs;
lhs =y(18);
rhs =y(28)-y(16);
residual(7)= lhs-rhs;
lhs =y(17);
rhs =y(33)-y(15);
residual(8)= lhs-rhs;
lhs =y(19);
rhs =y(17)-(1-params(19))*y(18);
residual(9)= lhs-rhs;
lhs =y(20);
rhs =y(22)-y(19);
residual(10)= lhs-rhs;
lhs =y(24);
rhs =y(26)*params(4)*(params(12)-params(11)*(1+params(19)*params(26)))/params(11)*(1-params(15))-y(27)*params(4)*(params(12)+(1-params(19))*params(26)*params(11))/params(11)*(1-params(16))+T60*(y(43)-y(32));
residual(11)= lhs-rhs;
lhs =y(29);
rhs =params(9)*(y(17)+y(22)*params(26))+y(40)*params(23);
residual(12)= lhs-rhs;
lhs =y(29);
rhs =y(11)-y(1);
residual(13)= lhs-rhs;
lhs =y(30);
rhs =params(9)*(y(17)+y(22)*params(26)-y(18))+y(41)*params(23);
residual(14)= lhs-rhs;
lhs =y(30);
rhs =y(12)-y(2);
residual(15)= lhs-rhs;
lhs =y(31);
rhs =params(23)*y(42)+params(9)*(y(22)*(1+params(26))-y(20))-params(19)*params(20)*(params(23)*(y(44)-y(33))-(y(33)-y(8)));
residual(16)= lhs-rhs;
lhs =y(33);
rhs =y(8)+y(34)-y(9)+y(36)-y(29);
residual(17)= lhs-rhs;
lhs =y(32);
rhs =params(27)*y(7)+x(it_, 1);
residual(18)= lhs-rhs;
lhs =y(36);
rhs =params(28)*y(10)+x(it_, 2);
residual(19)= lhs-rhs;
lhs =y(26);
rhs =params(15)*y(4)+x(it_, 3);
residual(20)= lhs-rhs;
lhs =y(27);
rhs =params(16)*y(5)+x(it_, 4);
residual(21)= lhs-rhs;
residual(22) = y(13)-T227*y(3)+y(20)*T234;
lhs =y(37);
rhs =y(32)+y(33)*params(11)-y(28)*params(12);
residual(23)= lhs-rhs;
lhs =y(28);
rhs =y(30)+y(6)-y(29);
residual(24)= lhs-rhs;
lhs =y(21);
rhs =params(19)*y(29)+(1-params(19))*y(30);
residual(25)= lhs-rhs;
lhs =y(21);
rhs =y(13)-y(3);
residual(26)= lhs-rhs;
lhs =y(25);
rhs =params(19)*y(26)+(1-params(19))*y(27);
residual(27)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(27, 48);

  %
  % Jacobian matrix
  %

  g1(1,14)=1;
  g1(1,28)=params(19)*params(20)*(1-params(19))*(params(21)-1);
  g1(1,33)=(-(params(19)*params(20)*(params(22)-1+params(20)*(params(19)+params(21)*(1-params(19)))+params(22)*params(13)-1)));
  g1(2,14)=(-1);
  g1(2,38)=1;
  g1(2,22)=1;
  g1(2,39)=(-1);
  g1(2,24)=(-1);
  g1(2,40)=(-params(19));
  g1(2,41)=(-(1-params(19)));
  g1(2,35)=1;
  g1(3,16)=params(4)*(params(12)-(1-params(19))*params(11))/params(11);
  g1(3,23)=1;
  g1(3,25)=(-(params(4)*(1+params(26))));
  g1(3,32)=(-T60);
  g1(4,15)=1;
  g1(4,16)=(-(params(12)*T74));
  g1(4,23)=(-T74);
  g1(4,32)=T74;
  g1(5,16)=1;
  g1(5,26)=(-1);
  g1(5,27)=1;
  g1(6,22)=1;
  g1(6,23)=1;
  g1(6,37)=(-1);
  g1(7,16)=1;
  g1(7,18)=1;
  g1(7,28)=(-1);
  g1(8,15)=1;
  g1(8,17)=1;
  g1(8,33)=(-1);
  g1(9,17)=(-1);
  g1(9,18)=1-params(19);
  g1(9,19)=1;
  g1(10,19)=1;
  g1(10,20)=1;
  g1(10,22)=(-1);
  g1(11,24)=1;
  g1(11,26)=(-(params(4)*(params(12)-params(11)*(1+params(19)*params(26)))/params(11)*(1-params(15))));
  g1(11,27)=params(4)*(params(12)+(1-params(19))*params(26)*params(11))/params(11)*(1-params(16));
  g1(11,32)=T60;
  g1(11,43)=(-T60);
  g1(12,17)=(-params(9));
  g1(12,22)=(-(params(26)*params(9)));
  g1(12,29)=1;
  g1(12,40)=(-params(23));
  g1(13,1)=1;
  g1(13,11)=(-1);
  g1(13,29)=1;
  g1(14,17)=(-params(9));
  g1(14,18)=params(9);
  g1(14,22)=(-(params(26)*params(9)));
  g1(14,30)=1;
  g1(14,41)=(-params(23));
  g1(15,2)=1;
  g1(15,12)=(-1);
  g1(15,30)=1;
  g1(16,20)=params(9);
  g1(16,22)=(-((1+params(26))*params(9)));
  g1(16,31)=1;
  g1(16,42)=(-params(23));
  g1(16,8)=params(19)*params(20);
  g1(16,33)=params(19)*params(20)*((-params(23))-1);
  g1(16,44)=params(19)*params(20)*params(23);
  g1(17,29)=1;
  g1(17,8)=(-1);
  g1(17,33)=1;
  g1(17,9)=1;
  g1(17,34)=(-1);
  g1(17,36)=(-1);
  g1(18,7)=(-params(27));
  g1(18,32)=1;
  g1(18,45)=(-1);
  g1(19,10)=(-params(28));
  g1(19,36)=1;
  g1(19,46)=(-1);
  g1(20,4)=(-params(15));
  g1(20,26)=1;
  g1(20,47)=(-1);
  g1(21,5)=(-params(16));
  g1(21,27)=1;
  g1(21,48)=(-1);
  g1(22,3)=(-T227);
  g1(22,13)=1;
  g1(22,20)=T234;
  g1(23,28)=params(12);
  g1(23,32)=(-1);
  g1(23,33)=(-params(11));
  g1(23,37)=1;
  g1(24,6)=(-1);
  g1(24,28)=1;
  g1(24,29)=1;
  g1(24,30)=(-1);
  g1(25,21)=1;
  g1(25,29)=(-params(19));
  g1(25,30)=(-(1-params(19)));
  g1(26,3)=1;
  g1(26,13)=(-1);
  g1(26,21)=1;
  g1(27,25)=1;
  g1(27,26)=(-params(19));
  g1(27,27)=(-(1-params(19)));

if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],27,2304);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],27,110592);
end
end
end
end
