function [residual, g1, g2, g3] = w1_nx_y_dynamic(y, x, params, steady_state, it_)
%
% Status : Computes dynamic model for Dynare
%
% Inputs :
%   y         [#dynamic variables by 1] double    vector of endogenous variables in the order stored
%                                                 in M_.lead_lag_incidence; see the Manual
%   x         [nperiods by M_.exo_nbr] double     matrix of exogenous variables (in declaration order)
%                                                 for all simulation periods
%   steady_state  [M_.endo_nbr by 1] double       vector of steady state values
%   params    [M_.param_nbr by 1] double          vector of parameter values in declaration order
%   it_       scalar double                       time period for exogenous variables for which to evaluate the model
%
% Outputs:
%   residual  [M_.endo_nbr by 1] double    vector of residuals of the dynamic model equations in order of 
%                                          declaration of the equations.
%                                          Dynare may prepend auxiliary equations, see M_.aux_vars
%   g1        [M_.endo_nbr by #dynamic variables] double    Jacobian matrix of the dynamic model equations;
%                                                           rows: equations in order of declaration
%                                                           columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g2        [M_.endo_nbr by (#dynamic variables)^2] double   Hessian matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%   g3        [M_.endo_nbr by (#dynamic variables)^3] double   Third order derivative matrix of the dynamic model equations;
%                                                              rows: equations in order of declaration
%                                                              columns: variables in order stored in M_.lead_lag_incidence followed by the ones in M_.exo_names
%
%
% Warning : this file is generated automatically by Dynare
%           from model file (.mod)

%
% Model equations
%

residual = zeros(27, 1);
T59 = (1+params(10)*params(11)*(params(12)-1))*(1-params(10)*params(11))+params(10)*params(11)*(params(13)+params(4)*(params(13)-params(12)));
T63 = T59/(1+T59*params(17));
T74 = (1-params(10))*(1+params(10)*params(11)*(params(12)-1));
T78 = T63*(T74-(1-params(10))*T59)/T59;
T84 = 1/T59;
T115 = T63*(T74-T59*(1+params(10)*params(17)))/T59;
T123 = T63*(T74+(1-params(10))*T59*params(17))/T59;
T141 = (1-params(14)*params(20))*(1-params(20))/params(20);
lhs =y(15);
rhs =params(10)*params(11)*(params(13)-1+params(11)*(params(10)+params(12)*(1-params(10)))+params(13)*params(4)-1)*y(34)-params(10)*params(11)*(1-params(10))*(params(12)-1)*y(29);
residual(1)= lhs-rhs;
lhs =y(23);
rhs =y(40)-(y(39)-y(15))-(y(36)-params(10)*y(41)-(1-params(10))*y(42)-y(25));
residual(2)= lhs-rhs;
lhs =y(24);
rhs =T63*(1+params(17))*y(26)+T63*(1-T59)/T59*y(33)-T78*y(17);
residual(3)= lhs-rhs;
lhs =y(16);
rhs =T84*(y(24)-y(33)+T74*y(17));
residual(4)= lhs-rhs;
lhs =y(17);
rhs =y(27)-y(28);
residual(5)= lhs-rhs;
lhs =y(23);
rhs =y(38)-y(24);
residual(6)= lhs-rhs;
lhs =y(19);
rhs =y(29)-y(17);
residual(7)= lhs-rhs;
lhs =y(18);
rhs =y(34)-y(16);
residual(8)= lhs-rhs;
lhs =y(20);
rhs =y(18)-(1-params(10))*y(19);
residual(9)= lhs-rhs;
lhs =y(21);
rhs =y(23)-y(20);
residual(10)= lhs-rhs;
lhs =y(25);
rhs =y(27)*T115*(1-params(6))-y(28)*T123*(1-params(7))-T63*(1-T59)/T59*y(33)*(1-params(18));
residual(11)= lhs-rhs;
lhs =y(30);
rhs =T141*(y(18)+y(23)*params(17))+y(41)*params(14);
residual(12)= lhs-rhs;
lhs =y(30);
rhs =y(12)-y(1);
residual(13)= lhs-rhs;
lhs =y(31);
rhs =T141*(y(18)+y(23)*params(17)-y(19))+y(42)*params(14);
residual(14)= lhs-rhs;
lhs =y(31);
rhs =y(13)-y(2);
residual(15)= lhs-rhs;
lhs =y(32);
rhs =params(14)*y(43)+T141*(y(23)*(1+params(17))-y(21))-params(10)*params(11)*(params(14)*(y(44)-y(34))-(y(34)-y(8)));
residual(16)= lhs-rhs;
lhs =y(34);
rhs =y(8)+y(35)-y(9)+y(37)-y(30);
residual(17)= lhs-rhs;
lhs =y(33);
rhs =params(18)*y(7)+x(it_, 1);
residual(18)= lhs-rhs;
lhs =y(37);
rhs =params(19)*y(11)+x(it_, 2);
residual(19)= lhs-rhs;
lhs =y(27);
rhs =params(6)*y(4)+x(it_, 3);
residual(20)= lhs-rhs;
lhs =y(28);
rhs =params(7)*y(5)+x(it_, 4);
residual(21)= lhs-rhs;
lhs =y(36);
rhs =params(5)*y(10)+(1-params(5))*(params(8)*(params(10)*y(30)+(1-params(10))*y(31))-y(15)*params(1)+y(23)*params(9));
residual(22)= lhs-rhs;
lhs =y(38);
rhs =y(33)+y(34)*T59-y(29)*T74;
residual(23)= lhs-rhs;
lhs =y(29);
rhs =y(31)+y(6)-y(30);
residual(24)= lhs-rhs;
lhs =y(22);
rhs =params(10)*y(30)+(1-params(10))*y(31);
residual(25)= lhs-rhs;
lhs =y(22);
rhs =y(14)-y(3);
residual(26)= lhs-rhs;
lhs =y(26);
rhs =params(10)*y(27)+(1-params(10))*y(28);
residual(27)= lhs-rhs;
if nargout >= 2,
  g1 = zeros(27, 48);

  %
  % Jacobian matrix
  %

  g1(1,15)=1;
  g1(1,29)=params(10)*params(11)*(1-params(10))*(params(12)-1);
  g1(1,34)=(-(params(10)*params(11)*(params(13)-1+params(11)*(params(10)+params(12)*(1-params(10)))+params(13)*params(4)-1)));
  g1(2,15)=(-1);
  g1(2,39)=1;
  g1(2,23)=1;
  g1(2,40)=(-1);
  g1(2,25)=(-1);
  g1(2,41)=(-params(10));
  g1(2,42)=(-(1-params(10)));
  g1(2,36)=1;
  g1(3,17)=T78;
  g1(3,24)=1;
  g1(3,26)=(-(T63*(1+params(17))));
  g1(3,33)=(-(T63*(1-T59)/T59));
  g1(4,16)=1;
  g1(4,17)=(-(T74*T84));
  g1(4,24)=(-T84);
  g1(4,33)=T84;
  g1(5,17)=1;
  g1(5,27)=(-1);
  g1(5,28)=1;
  g1(6,23)=1;
  g1(6,24)=1;
  g1(6,38)=(-1);
  g1(7,17)=1;
  g1(7,19)=1;
  g1(7,29)=(-1);
  g1(8,16)=1;
  g1(8,18)=1;
  g1(8,34)=(-1);
  g1(9,18)=(-1);
  g1(9,19)=1-params(10);
  g1(9,20)=1;
  g1(10,20)=1;
  g1(10,21)=1;
  g1(10,23)=(-1);
  g1(11,25)=1;
  g1(11,27)=(-(T115*(1-params(6))));
  g1(11,28)=T123*(1-params(7));
  g1(11,33)=T63*(1-T59)/T59*(1-params(18));
  g1(12,18)=(-T141);
  g1(12,23)=(-(params(17)*T141));
  g1(12,30)=1;
  g1(12,41)=(-params(14));
  g1(13,1)=1;
  g1(13,12)=(-1);
  g1(13,30)=1;
  g1(14,18)=(-T141);
  g1(14,19)=T141;
  g1(14,23)=(-(params(17)*T141));
  g1(14,31)=1;
  g1(14,42)=(-params(14));
  g1(15,2)=1;
  g1(15,13)=(-1);
  g1(15,31)=1;
  g1(16,21)=T141;
  g1(16,23)=(-((1+params(17))*T141));
  g1(16,32)=1;
  g1(16,43)=(-params(14));
  g1(16,8)=params(10)*params(11);
  g1(16,34)=params(10)*params(11)*((-params(14))-1);
  g1(16,44)=params(10)*params(11)*params(14);
  g1(17,30)=1;
  g1(17,8)=(-1);
  g1(17,34)=1;
  g1(17,9)=1;
  g1(17,35)=(-1);
  g1(17,37)=(-1);
  g1(18,7)=(-params(18));
  g1(18,33)=1;
  g1(18,45)=(-1);
  g1(19,11)=(-params(19));
  g1(19,37)=1;
  g1(19,46)=(-1);
  g1(20,4)=(-params(6));
  g1(20,27)=1;
  g1(20,47)=(-1);
  g1(21,5)=(-params(7));
  g1(21,28)=1;
  g1(21,48)=(-1);
  g1(22,15)=(-((1-params(5))*(-params(1))));
  g1(22,23)=(-((1-params(5))*params(9)));
  g1(22,30)=(-((1-params(5))*params(10)*params(8)));
  g1(22,31)=(-((1-params(5))*(1-params(10))*params(8)));
  g1(22,10)=(-params(5));
  g1(22,36)=1;
  g1(23,29)=T74;
  g1(23,33)=(-1);
  g1(23,34)=(-T59);
  g1(23,38)=1;
  g1(24,6)=(-1);
  g1(24,29)=1;
  g1(24,30)=1;
  g1(24,31)=(-1);
  g1(25,22)=1;
  g1(25,30)=(-params(10));
  g1(25,31)=(-(1-params(10)));
  g1(26,3)=1;
  g1(26,14)=(-1);
  g1(26,22)=1;
  g1(27,26)=1;
  g1(27,27)=(-params(10));
  g1(27,28)=(-(1-params(10)));

if nargout >= 3,
  %
  % Hessian matrix
  %

  g2 = sparse([],[],[],27,2304);
if nargout >= 4,
  %
  % Third order derivatives
  %

  g3 = sparse([],[],[],27,110592);
end
end
end
end
